@@ -1,6 +1,11 @@
  N_( "The GnuCash online manual has lots of helpful information. \
 You can access the manual under the Help menu.")
 
+/* Translators: You can replace the link, if a translated page exists. */
+ N_( "Mailing lists are the preferred form of communication in the \
+GnuCash community. For announcements of new releases, user groups etc. \
+see the table at https://wiki.gnucash.org/wiki/Mailing_Lists")
+
  N_( "The GnuCash developers are easy to contact. As well \
 as several mailing lists, you can chat to them live on IRC! \
 Join them on #gnucash at irc.gnome.org")
@@ -30,6 +35,12 @@ account details. For more information on choosing an account type \
 or setting up a chart of accounts, please see the GnuCash online \
 manual.")
 
+N_( "Every transaction has a \"Notes\" field where you can put useful \
+information.\n\n\
+To make it visible\n\
+select \"View\" in the menu bar and check \"Double Line\" or\n\
+check \"Double Line Mode\" in Preferences:Register Defaults.")
+
  N_( "To enter multiple-split transactions such as a paycheck with \
 multiple deductions, click the Split button in the tool bar. \
 Alternatively, in the View menu, you can choose the register \
