@@ -367,6 +367,15 @@ gnc_search_dialog_display_results (GNCSearchWindow *sw)
     max_count = gnc_prefs_get_float(GNC_PREFS_GROUP_SEARCH_GENERAL, GNC_PREF_NEW_SEARCH_LIMIT);
     if (gnc_query_view_get_num_entries(GNC_QUERY_VIEW(sw->result_view)) < max_count)
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (sw->new_rb), TRUE);
+
+    /* If there is only one item then select it */
+    if (gnc_query_view_get_num_entries (GNC_QUERY_VIEW(sw->result_view)) == 1)
+    {
+        GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(sw->result_view));
+        GtkTreePath *path = gtk_tree_path_new_first ();
+        gtk_tree_selection_select_path (selection, path);
+        gtk_tree_path_free (path);
+    }
 }
 
 static void
@@ -644,7 +653,7 @@ search_cancel_cb (GtkButton *button, GNCSearchWindow *sw)
 static void
 search_help_cb (GtkButton *button, GNCSearchWindow *sw)
 {
-    gnc_gnome_help (HF_HELP, HL_FIND_TRANSACTIONS);
+    gnc_gnome_help (GTK_WINDOW(sw->dialog), HF_HELP, HL_FIND_TRANSACTIONS);
 }
 
 static void
@@ -1127,8 +1136,9 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw, const gchar *title)
     gtk_window_set_title(GTK_WINDOW(sw->dialog), title);
     g_object_set_data (G_OBJECT (sw->dialog), "dialog-info", sw);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(sw->dialog), "GncSearchDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(sw->dialog), "gnc-id-search");
+    gnc_widget_style_context_add_class (GTK_WIDGET(sw->dialog), "gnc-class-search");
 
     /* Grab the result hbox */
     sw->result_hbox = GTK_WIDGET(gtk_builder_get_object (builder, "result_hbox"));
@@ -1328,11 +1338,9 @@ gnc_search_dialog_create (GtkWindow *parent,
                                                 gtk_widget_get_allocated_height (
                                                 GTK_WIDGET(sw->grouping_combo)) * 1.5);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    if (style_class == NULL)
-        gnc_widget_set_style_context (GTK_WIDGET(sw->dialog), "GncSearchDialog");
-    else
-        gnc_widget_set_style_context (GTK_WIDGET(sw->dialog), style_class);
+    // Add a style context for this dialog so it can be easily manipulated with css
+    if (style_class != NULL)
+        gnc_widget_style_context_add_class (GTK_WIDGET(sw->dialog), style_class);
 
     /* Maybe display the original query results? */
     if (callbacks && show_start_query)
