@@ -103,13 +103,7 @@ find_or_create_txn(struct CloseAccountsCB* cacb, gnc_commodity* cmdty)
         txn->txn = xaccMallocTransaction(cacb->cbw->book);
         xaccTransBeginEdit(txn->txn);
         xaccTransSetDateEnteredSecs(txn->txn, gnc_time (NULL));
-
-        /* Watch out: The book-closing txn currently assume that their
-        posted-date is the end date plus 12 hours, so that the closing txn can
-        be distinguished from normal txns of the last day. This is the only
-        case within GnuCash where the PostedDate is a different time-of-day
-        that what the GDate normally says as a normalized date. */
-        xaccTransSetDatePostedSecs(txn->txn, cacb->cbw->close_date);
+        xaccTransSetDatePostedSecsNormalized(txn->txn, cacb->cbw->close_date);
 
         xaccTransSetDescription(txn->txn, cacb->cbw->desc);
         xaccTransSetCurrency(txn->txn, cmdty);
@@ -142,7 +136,7 @@ static void close_accounts_cb(Account *a, gpointer data)
     if (cacb->acct_type != xaccAccountGetType(a))
         return;
 
-    bal = xaccAccountGetBalanceAsOfDate(a, cacb->cbw->close_date + 1);
+    bal = xaccAccountGetBalanceAsOfDate(a, gnc_time64_get_day_end (cacb->cbw->close_date));
     if (gnc_numeric_zero_p(bal))
         return;
 
@@ -285,11 +279,10 @@ gnc_book_close_response_cb(GtkDialog *dialog, gint response, GtkDialog *unused)
     switch (response)
     {
     case GTK_RESPONSE_HELP:
-        gnc_gnome_help(HF_HELP, HL_CLOSE_BOOK);
+        gnc_gnome_help (GTK_WINDOW(dialog), HF_HELP, HL_CLOSE_BOOK);
         break;
     case GTK_RESPONSE_OK:
         cbw->close_date = gnc_date_edit_get_date(GNC_DATE_EDIT(cbw->close_date_widget));
-        cbw->close_date += (3600 * 12);  /* Add 12 hours to the timestamp */
         cbw->desc = gtk_entry_get_text(GTK_ENTRY(cbw->desc_widget));
 
         income_acct = gnc_account_sel_get_account(GNC_ACCOUNT_SEL(cbw->income_acct_widget));
@@ -340,8 +333,8 @@ void gnc_ui_close_book (QofBook* book, GtkWindow *parent)
     gnc_builder_add_from_file (builder, "dialog-book-close.glade", "close_book_dialog");
     cbw->dialog = GTK_WIDGET(gtk_builder_get_object (builder,  "close_book_dialog"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(cbw->dialog), "GncBookCloseDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(cbw->dialog), "gnc-id-book-close");
 
     /* parent */
     if (parent != NULL)
@@ -358,6 +351,7 @@ void gnc_ui_close_book (QofBook* book, GtkWindow *parent)
     equity_list = g_list_prepend(equity_list, GINT_TO_POINTER(ACCT_TYPE_EQUITY));
     box = GTK_WIDGET(gtk_builder_get_object (builder, "income_acct_box"));
     cbw->income_acct_widget = gnc_account_sel_new();
+    gnc_account_sel_set_hexpand (GNC_ACCOUNT_SEL(cbw->income_acct_widget), TRUE);
     gnc_account_sel_set_acct_filters(GNC_ACCOUNT_SEL(cbw->income_acct_widget),
                                      equity_list, NULL);
     gnc_account_sel_set_new_account_ability(GNC_ACCOUNT_SEL(cbw->income_acct_widget), TRUE);
@@ -366,6 +360,7 @@ void gnc_ui_close_book (QofBook* book, GtkWindow *parent)
     /* expense acct */
     box = GTK_WIDGET(gtk_builder_get_object (builder, "expense_acct_box"));
     cbw->expense_acct_widget = gnc_account_sel_new();
+    gnc_account_sel_set_hexpand (GNC_ACCOUNT_SEL(cbw->expense_acct_widget), TRUE);
     gnc_account_sel_set_acct_filters(GNC_ACCOUNT_SEL(cbw->expense_acct_widget),
                                      equity_list, NULL);
     gnc_account_sel_set_new_account_ability(GNC_ACCOUNT_SEL(cbw->expense_acct_widget), TRUE);
