@@ -106,9 +106,6 @@ struct commodity_window
 typedef struct select_commodity_window SelectCommodityWindow;
 typedef struct commodity_window CommodityWindow;
 
-static gnc_commodity_help_callback help_callback = NULL;
-
-
 /* The commodity selection window */
 static SelectCommodityWindow *
 gnc_ui_select_commodity_create(const gnc_commodity * orig_sel,
@@ -129,17 +126,6 @@ gboolean gnc_ui_commodity_dialog_to_object(CommodityWindow * w);
 static void gnc_ui_select_commodity_response_cb (GtkDialog * dialog, gint response, gpointer data);
 #endif
 
-
-/********************************************************************
- * gnc_ui_commodity_set_help_callback
- ********************************************************************/
-void
-gnc_ui_commodity_set_help_callback (gnc_commodity_help_callback cb)
-{
-    help_callback = cb;
-}
-
-
 /********************************************************************
  * gnc_ui_select_commodity_modal_full()
  ********************************************************************/
@@ -183,7 +169,8 @@ gnc_ui_select_commodity_modal_full(gnc_commodity * orig_sel,
                         /* Translators: Replace here and later CUSIP by the name of your local
                            National Securities Identifying Number
                            like gb:SEDOL, de:WKN, ch:Valorennummer, fr:SICOVAM ...
-                           See http://en.wikipedia.org/wiki/ISIN for hints. */
+                           See http://en.wikipedia.org/wiki/ISIN and
+                           https://en.wikipedia.org/wiki/National_numbering_agency for hints. */
                         cusip    ? _("\nExchange code (ISIN, CUSIP or similar): ") : "",
                         cusip    ? cusip : "",
                         mnemonic ? _("\nMnemonic (Ticker symbol or similar): ") : "",
@@ -266,8 +253,9 @@ gnc_ui_select_commodity_create(const gnc_commodity * orig_sel,
     retval->ok_button = GTK_WIDGET(gtk_builder_get_object (builder, "ss_ok_button"));
     label = GTK_WIDGET(gtk_builder_get_object (builder, "item_label"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(retval->dialog), "GncSecurityDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(retval->dialog), "gnc-id-security-select");
+    gnc_widget_style_context_add_class (GTK_WIDGET(retval->dialog), "gnc-class-securities");
 
     gnc_cbwe_require_list_item(GTK_COMBO_BOX(retval->namespace_combo));
     gnc_cbwe_require_list_item(GTK_COMBO_BOX(retval->commodity_combo));
@@ -889,7 +877,6 @@ gnc_ui_build_commodity_dialog(const char * selected_namespace,
                               gboolean     edit)
 {
     CommodityWindow * retval = g_new0(CommodityWindow, 1);
-    GtkWidget *help_button;
     GtkWidget *box;
     GtkWidget *menu;
     GtkWidget *widget, *sec_label;
@@ -910,18 +897,15 @@ gnc_ui_build_commodity_dialog(const char * selected_namespace,
 
     retval->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "security_dialog"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(retval->dialog), "GncSecurityDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(retval->dialog), "gnc-id-security");
+    gnc_widget_style_context_add_class (GTK_WIDGET(retval->dialog), "gnc-class-securities");
 
     if (parent != NULL)
         gtk_window_set_transient_for (GTK_WINDOW (retval->dialog), GTK_WINDOW (parent));
 
     retval->edit_commodity = NULL;
 
-    help_button = GTK_WIDGET(gtk_builder_get_object (builder, "help_button"));
-    if (!help_callback)
-        gtk_widget_hide (help_button);
-
     /* Get widget pointers */
     retval->fullname_entry = GTK_WIDGET(gtk_builder_get_object (builder, "fullname_entry"));
     retval->mnemonic_entry = GTK_WIDGET(gtk_builder_get_object (builder, "mnemonic_entry"));
@@ -1156,8 +1140,7 @@ gnc_ui_common_commodity_modal(gnc_commodity *commodity,
             break;
         case GTK_RESPONSE_HELP:
             DEBUG("case HELP");
-            if (help_callback)
-                help_callback ();
+            gnc_gnome_help (GTK_WINDOW(win->dialog), HF_HELP, HL_COMMODITY);
             break;
         default:	/* Cancel, Escape, Close, etc. */
             DEBUG("default: %d", value);
