@@ -47,7 +47,7 @@
 #include "swig-runtime.h"
 #include "guile-mappings.h"
 #include "engine-helpers.h"
-#include "engine-helpers-guile.h"
+#include "gnc-engine-guile.h"
 #include "QuickFill.h"
 #include <gnc-commodity.h>
 
@@ -1514,7 +1514,7 @@ create_transaction(XferDialog *xferData, time64 time,
     xaccTransBeginEdit(trans);
 
     xaccTransSetCurrency(trans, xferData->from_commodity);
-    xaccTransSetDatePostedSecs(trans, time);
+    xaccTransSetDatePostedSecsNormalized(trans, time);
 
     /* Trans-Num or Split-Action set with gnc_set_num_action below per book
      * option */
@@ -1634,7 +1634,6 @@ new_price(XferDialog *xferData, time64 time)
     else if (from == gnc_default_currency() && to != gnc_default_currency())
         value = swap_commodities (&from, &to, value);
 
-    value = round_price (from, to, value);
     price = gnc_price_create (xferData->book);
     gnc_price_begin_edit (price);
     gnc_price_set_commodity (price, from);
@@ -1885,8 +1884,9 @@ gnc_xfer_dialog_create(GtkWidget *parent, XferDialog *xferData)
     xferData->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "transfer_dialog"));
     g_object_set_data_full (G_OBJECT (xferData->dialog), "builder", builder, g_object_unref);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(xferData->dialog), "GncTransferDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(xferData->dialog), "gnc-id-transfer");
+    gnc_widget_style_context_add_class (GTK_WIDGET(xferData->dialog), "gnc-class-securities");
 
     /* parent */
     if (parent != NULL)
