@@ -193,8 +193,8 @@ gnc_currency_edit_class_init (GNCCurrencyEditClass *klass)
 static void
 gnc_currency_edit_init (GNCCurrencyEdit *gce)
 {
-    // Set the style context for this widget so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(gce), "GncCurrencyEdit");
+    // Set the name for this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(gce), "gnc-id-currency-edit");
 
     g_signal_connect (gce, "notify::mnemonic",
                       G_CALLBACK (gnc_currency_edit_mnemonic_changed), gce);
@@ -269,14 +269,19 @@ static void gnc_currency_edit_active_changed (GtkComboBox *gobject,
 {
     GNCCurrencyEdit *self = GNC_CURRENCY_EDIT (gobject);
 
-    gnc_commodity *currency = gnc_currency_edit_get_currency (self);
-    const gchar *mnemonic = gnc_commodity_get_mnemonic (currency);
+    /* Check that there is a proper selection before proceeding.  Doing so allows
+     * GTK entry completion to proceed. */
+    if (gtk_combo_box_get_active(GTK_COMBO_BOX(self)) != -1)
+    {
+        gnc_commodity *currency = gnc_currency_edit_get_currency (self);
+        const gchar *mnemonic = gnc_commodity_get_mnemonic (currency);
 
-    g_signal_handlers_block_by_func(G_OBJECT(self),
-                                    G_CALLBACK(gnc_currency_edit_active_changed), user_data);
-    g_object_set (G_OBJECT (self), "mnemonic", mnemonic, NULL);
-    g_signal_handlers_unblock_by_func(G_OBJECT(self),
-                                      G_CALLBACK(gnc_currency_edit_active_changed), user_data);
+        g_signal_handlers_block_by_func(G_OBJECT(self),
+                                        G_CALLBACK(gnc_currency_edit_active_changed), user_data);
+        g_object_set (G_OBJECT (self), "mnemonic", mnemonic, NULL);
+        g_signal_handlers_unblock_by_func(G_OBJECT(self),
+                                        G_CALLBACK(gnc_currency_edit_active_changed), user_data);
+    }
 }
 
 /** This auxiliary function adds a single currency name to the combo
