@@ -222,9 +222,7 @@ gnc_dense_cal_class_init(GncDenseCalClass *klass)
     object_class = G_OBJECT_CLASS (klass);
     widget_class = GTK_WIDGET_CLASS (klass);
 
-#if GTK_CHECK_VERSION(3,20,0)
     gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(klass), "calendar");
-#endif
 
     parent_class = g_type_class_peek_parent (klass);
 
@@ -267,9 +265,10 @@ gnc_dense_cal_init(GncDenseCal *dcal)
     gtk_orientable_set_orientation (GTK_ORIENTABLE(dcal), GTK_ORIENTATION_VERTICAL);
 
     // Set the style context for this widget so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dcal), "calendar");
+    gnc_widget_style_context_add_class (GTK_WIDGET(dcal), "calendar");
 
-    gtk_widget_set_name (GTK_WIDGET(dcal), "dense-cal");
+    // Set the name of this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dcal), "gnc-id-dense-calendar");
 
     gtk_style_context_add_class (context, GTK_STYLE_CLASS_CALENDAR);
     {
@@ -292,11 +291,7 @@ gnc_dense_cal_init(GncDenseCal *dcal)
 
         gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
         gtk_widget_set_halign (label, GTK_ALIGN_END);
-#if GTK_CHECK_VERSION(3,12,0)
         gtk_widget_set_margin_end (label, 5);
-#else
-        gtk_widget_set_margin_right (label, 5);
-#endif
         gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
         gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(dcal->view_options), FALSE, FALSE, 0);
 
@@ -335,14 +330,10 @@ gnc_dense_cal_init(GncDenseCal *dcal)
         hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
         gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
 
-        gtk_widget_set_name (GTK_WIDGET(dcal->transPopup), "dense-cal-popup");
+        gtk_widget_set_name (GTK_WIDGET(dcal->transPopup), "gnc-id-dense-calendar-popup");
 
         l = gtk_label_new(_("Date: "));
-#if GTK_CHECK_VERSION(3,12,0)
         gtk_widget_set_margin_start (l, 5);
-#else
-        gtk_widget_set_margin_left (l, 5);
-#endif
         gtk_container_add(GTK_CONTAINER(hbox), l);
         l = gtk_label_new("YY/MM/DD");
         g_object_set_data(G_OBJECT(dcal->transPopup), "dateLabel", l);
@@ -421,8 +412,8 @@ gnc_dense_cal_init(GncDenseCal *dcal)
 
     dcal->numMonths = 12;
     dcal->monthsPerCol = 3;
-    dcal->leftPadding = 2;
-    dcal->topPadding = 2;
+    dcal->leftPadding = 4;
+    dcal->topPadding = 4;
 
     {
     GDate now;
@@ -1002,10 +993,8 @@ gnc_dense_cal_draw_to_buffer(GncDenseCal *dcal)
 
         gtk_style_context_save (stylectxt);
         gtk_style_context_add_class (stylectxt, marker_color_class);
-#if GTK_CHECK_VERSION(3,22,0)
         gtk_style_context_add_class (stylectxt, GTK_STYLE_CLASS_VIEW);
         gtk_style_context_set_state (stylectxt, GTK_STATE_FLAG_SELECTED);
-#endif
 
         for (i = 0; i < dcal->numMarks; i++)
         {
@@ -1018,15 +1007,16 @@ gnc_dense_cal_draw_to_buffer(GncDenseCal *dcal)
                 center_y = (y1 + y2 ) / 2;
                 radius = MIN((x2 - x1), (y2 - y1)) * .75;
 
-                // try to compensate for row height being odd or even
-                if (((y2 -y1) % 2) == 0)
-                    gtk_render_background (stylectxt, cr,
-                                           center_x - radius - 2, center_y - radius - 1,
-                                            (radius * 2) + 4, radius * 2);
-                else
-                    gtk_render_background (stylectxt, cr,
-                                           center_x - radius - 2, center_y - radius,
-                                            (radius * 2) + 4, (radius * 2) + 1);
+                // try to compensate for row height/width being odd or even
+                if (((y2 - y1) % 2) != 0)
+                    center_y = center_y + 1;
+
+                if (((x2 - x1) % 2) != 0)
+                    center_x = center_x + 1;
+
+                gtk_render_background (stylectxt, cr,
+                                       center_x - (radius + 2), center_y - radius,
+                                        (radius * 2) + 4, radius * 2);
             }
         }
         gtk_style_context_restore (stylectxt);
@@ -1044,7 +1034,7 @@ gnc_dense_cal_draw_to_buffer(GncDenseCal *dcal)
 
         x = dcal->leftPadding
             + (i * (col_width(dcal) + COL_BORDER_SIZE))
-            + dcal->label_width;
+            + dcal->label_height + 1;
         y = dcal->topPadding + dcal->dayLabelHeight;
         w = col_width(dcal) - COL_BORDER_SIZE - dcal->label_width;
         h = col_height(dcal);
@@ -1118,7 +1108,7 @@ gnc_dense_cal_draw_to_buffer(GncDenseCal *dcal)
     /* Month labels. */
     {
         gint i;
-        gint x_offset = dcal->label_height - (dcal->leftPadding * 2);
+        gint x_offset = dcal->leftPadding;
 
         gtk_style_context_save (stylectxt);
         gtk_style_context_add_class (stylectxt, GTK_STYLE_CLASS_HEADER);
@@ -1128,8 +1118,8 @@ gnc_dense_cal_draw_to_buffer(GncDenseCal *dcal)
             if (dcal->monthPositions[i].x == -1)
                 break;
 
-            gtk_render_background (stylectxt, cr, dcal->monthPositions[i].x + x_offset + 1, dcal->topPadding,
-                                   dcal->dayLabelHeight, col_height(dcal) + dcal->dayLabelHeight + 1);
+            gtk_render_background (stylectxt, cr, dcal->monthPositions[i].x + x_offset, dcal->topPadding,
+                                   dcal->dayLabelHeight + 1, col_height(dcal) + dcal->dayLabelHeight + 1);
         }
 
         for (i = 0; i < 12; i++)
@@ -1258,27 +1248,18 @@ static gint
 gnc_dense_cal_button_press(GtkWidget *widget,
                            GdkEventButton *evt)
 {
-#if GTK_CHECK_VERSION(3,22,0)
     GdkWindow *win = gdk_screen_get_root_window (gtk_widget_get_screen (widget));
     GdkMonitor *mon = gdk_display_get_monitor_at_window (gtk_widget_get_display (widget), win);
     GdkRectangle work_area_size;
-#else
-    GdkScreen *screen = gdk_screen_get_default ();
-#endif
     GtkAllocation alloc;
     GncDenseCal *dcal = GNC_DENSE_CAL(widget);
     gint win_xpos = evt->x_root + 5;
     gint win_ypos = evt->y_root + 5;
 
-#if GTK_CHECK_VERSION(3,22,0)
     gdk_monitor_get_workarea (mon, &work_area_size);
 
     dcal->screen_width = work_area_size.width;
     dcal->screen_height = work_area_size.height;
-#else
-    dcal->screen_width = gdk_screen_get_width (screen);
-    dcal->screen_height = gdk_screen_get_height (screen);
-#endif
 
     dcal->doc = wheres_this(dcal, evt->x, evt->y);
     dcal->showPopup = ~(dcal->showPopup);
@@ -1333,13 +1314,8 @@ gnc_dense_cal_motion_notify(GtkWidget *widget,
     /* As per https://www.gtk.org/tutorial/sec-eventhandling.html */
     if (event->is_hint)
     {
-#if GTK_CHECK_VERSION(3,20,0)
         GdkSeat *seat = gdk_display_get_default_seat (gdk_window_get_display (event->window));
         GdkDevice *pointer = gdk_seat_get_pointer (seat);
-#else
-        GdkDeviceManager *device_manager = gdk_display_get_device_manager (gdk_window_get_display (event->window));
-        GdkDevice *pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
 
         gdk_window_get_device_position (event->window, pointer,  &unused,  &unused, &unused2);
     }
@@ -1591,7 +1567,7 @@ month_coords(GncDenseCal *dcal, int monthOfCal, GList **outList)
         rect->x = dcal->leftPadding
                   + MINOR_BORDER_SIZE
                   + (colNum * (col_width(dcal) + COL_BORDER_SIZE))
-                  + dcal->label_width
+                  + dcal->label_height
                   + (start * day_width(dcal));
         rect->y = dcal->topPadding
                   + dcal->dayLabelHeight
@@ -1618,7 +1594,7 @@ month_coords(GncDenseCal *dcal, int monthOfCal, GList **outList)
             rect = g_new0(GdkRectangle, 1);
             rect->x = dcal->leftPadding
                       + MINOR_BORDER_SIZE
-                      + dcal->label_width
+                      + dcal->label_height
                       + (colNum * (col_width(dcal) + COL_BORDER_SIZE));
             rect->y = dcal->topPadding
                       + dcal->dayLabelHeight
@@ -1645,7 +1621,7 @@ month_coords(GncDenseCal *dcal, int monthOfCal, GList **outList)
         rect = g_new0(GdkRectangle, 1);
         rect->x = dcal->leftPadding
                   + MINOR_BORDER_SIZE
-                  + dcal->label_width
+                  + dcal->label_height
                   + (colNum * (col_width(dcal) + COL_BORDER_SIZE));
         rect->y = dcal->topPadding
                   + MINOR_BORDER_SIZE
@@ -1711,7 +1687,7 @@ doc_coords(GncDenseCal *dcal, int dayOfCal,
      * which it shouldn't. */
     *x1 = dcal->leftPadding
           + MINOR_BORDER_SIZE
-          + dcal->label_width
+          + dcal->label_height
           + (colNum * (col_width(dcal) + COL_BORDER_SIZE))
           + (dayCol * day_width(dcal))
           + (day_width(dcal) / 4);
@@ -1939,10 +1915,13 @@ gdc_model_added_cb(GncDenseCalModel *model, guint added_tag, gpointer user_data)
 static void
 gdc_model_update_cb(GncDenseCalModel *model, guint update_tag, gpointer user_data)
 {
-    GncDenseCal *cal = GNC_DENSE_CAL(user_data);
-    g_debug("gdc_model_update_cb update for tag [%d]\n", update_tag);
-    gdc_mark_remove(cal, update_tag, FALSE);
-    gdc_add_tag_markings(cal, update_tag);
+    GncDenseCal *cal = GNC_DENSE_CAL (user_data);
+    gint num_marks = 0;
+    g_debug ("gdc_model_update_cb update for tag [%d]\n", update_tag);
+    num_marks = gnc_dense_cal_model_get_instance_count (cal->model, update_tag);
+    // We need to redraw if there are no mark, to ensure they're all erased.
+    gdc_mark_remove (cal, update_tag, num_marks==0);
+    gdc_add_tag_markings (cal, update_tag);
 
 }
 
