@@ -191,8 +191,8 @@ gnc_query_view_init (GNCQueryView *qview)
 {
     GNCQueryViewPrivate *priv;
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(qview), "GncQueryView");
+    // Set the name for this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(qview), "gnc-id-query-view-view");
 
     qview->query = NULL;
 
