@@ -198,7 +198,11 @@ GtkTreeViewColumn * gnc_tree_view_account_add_custom_column(
     GncTreeViewAccount *view, const gchar *column_title,
     GncTreeViewAccountColumnSource source_cb,
     GncTreeViewAccountColumnTextEdited edited_cb);
-
+GtkTreeViewColumn *gnc_tree_view_account_add_custom_column_renderer(
+    GncTreeViewAccount *account_view, const gchar *column_title,
+    GncTreeViewAccountColumnSource col_source_cb,
+    GncTreeViewAccountColumnTextEdited col_edited_cb,
+    GtkCellRenderer *renderer);
 void gnc_tree_view_account_set_name_edited(GncTreeViewAccount *view,
         GncTreeViewAccountColumnTextEdited edited_cb);
 void gnc_tree_view_account_name_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_name);
@@ -406,7 +410,7 @@ Account * gnc_tree_view_account_get_selected_account (GncTreeViewAccount *view);
 
 /** This function selects an account in the account tree view.  All
  *  other accounts will be unselected.  In addition, this function
- *  collapses the entitre tree and then expands only the path to the
+ *  collapses the entire tree and then expands only the path to the
  *  selected account, making the item easy to find.  In general, this
  *  routine only need be called when initially putting up a window
  *  containing an account tree view widget.
@@ -439,7 +443,7 @@ GList * gnc_tree_view_account_get_selected_accounts (GncTreeViewAccount *view);
 
 /** This function selects a set of accounts in the account tree view.
  *  All other accounts will be unselected.  In addition, this function
- *  collapses the entitre tree and then expands only the path to the
+ *  collapses the entire tree and then expands only the path to the
  *  selected accounts, making them easy to find.  In general, this
  *  routine only need be called when initially putting up a window
  *  containing an account tree view widget.
