@@ -342,7 +342,7 @@ gnc_tree_view_commodity_new (QofBook *book,
 
     /* Create our view */
     view = g_object_new (GNC_TYPE_TREE_VIEW_COMMODITY,
-                         "name", "commodity_tree", NULL);
+                         "name", "gnc-id-commodity-tree", NULL);
     gtk_tree_view_set_model (GTK_TREE_VIEW (view), s_model);
     g_object_unref(G_OBJECT(s_model));
 
