@@ -43,6 +43,7 @@
 #include "gnc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
 #include "gnc-cell-renderer-date.h"
+#include "gnc-cell-renderer-text-view.h"
 #include "gnc-state.h"
 #include "gnc-prefs.h"
 #include "dialog-utils.h"
@@ -256,8 +257,8 @@ gnc_tree_view_init (GncTreeView *view, void *data)
     priv->sort_column_changed_cb_id = 0;
     priv->size_allocate_cb_id = 0;
 
-    // Set the style context for this page so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(view), "GncTreeView");
+    // Set the name for this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(view), "gnc-id-tree-view");
 
     /* Handle column drag and drop */
     gtk_tree_view_set_column_drag_function (GTK_TREE_VIEW(view),
@@ -273,16 +274,13 @@ gnc_tree_view_init (GncTreeView *view, void *data)
     /* Create the last column which contains the column selection
      * widget.  gnc_tree_view_add_text_column will do most of the
      * work. */
-    icon = gtk_image_new_from_icon_name ("go-down", GTK_ICON_SIZE_SMALL_TOOLBAR);
+    icon = gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_SMALL_TOOLBAR);
 
     priv->column_menu_icon_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_set_homogeneous (GTK_BOX(priv->column_menu_icon_box), FALSE);
 
-#if GTK_CHECK_VERSION(3,12,0)
     gtk_widget_set_margin_start (GTK_WIDGET(icon), 5);
-#else
-    gtk_widget_set_margin_left (GTK_WIDGET(icon), 5);
-#endif
+
     gtk_box_pack_end (GTK_BOX(priv->column_menu_icon_box), icon, FALSE, FALSE, 0);
 
     sep = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
@@ -290,9 +288,6 @@ gnc_tree_view_init (GncTreeView *view, void *data)
 
     gtk_widget_show_all (priv->column_menu_icon_box);
 
-    g_signal_connect (G_OBJECT(icon), "draw",
-                      G_CALLBACK(gnc_draw_arrow_cb), GINT_TO_POINTER(1));
-
     column = gnc_tree_view_add_text_column (view, NULL, NULL, NULL, NULL,
                                             -1, -1, NULL);
     g_object_set (G_OBJECT(column),
@@ -1404,12 +1399,7 @@ gnc_tree_view_select_column_cb (GtkTreeViewColumn *column,
     gtk_widget_show_all (menu);
 
     /* Pop the menu up at the button */
-#if GTK_CHECK_VERSION(3,22,0)
     gtk_menu_popup_at_pointer (GTK_MENU(priv->column_menu), NULL);
-#else
-    gtk_menu_popup (GTK_MENU(priv->column_menu), NULL, GTK_WIDGET(menu),
-                    NULL, NULL, 0, gtk_get_current_event_time ());
-#endif
 }
 
 
@@ -1830,26 +1820,18 @@ renderer_edited_cb (GtkCellRendererText *renderer, gchar *path,
         (priv->editing_finished_cb)(view, priv->editing_cb_data);
 }
 
-/** This function adds a new text column to a GncTreeView base view.
- *  It takes all the parameters necessary to hook a GtkTreeModel
- *  column to a GtkTreeViewColumn.  If the tree has a state section
- *  associated with it, this function also wires up the column so that
- *  its visibility and width are remembered.
- *
- *  Parameters are defined in gnc-tree-view.h
- */
-GtkTreeViewColumn *
-gnc_tree_view_add_text_column (GncTreeView *view,
-                               const gchar *column_title,
-                               const gchar *pref_name,
-                               const gchar *icon_name,
-                               const gchar *sizing_text,
-                               gint model_data_column,
-                               gint model_visibility_column,
-                               GtkTreeIterCompareFunc column_sort_fn)
+
+static GtkTreeViewColumn *
+add_text_column_variant (GncTreeView *view, GtkCellRenderer *renderer,
+                         const gchar *column_title,
+                         const gchar *pref_name,
+                         const gchar *icon_name,
+                         const gchar *sizing_text,
+                         gint model_data_column,
+                         gint model_visibility_column,
+                         GtkTreeIterCompareFunc column_sort_fn)
 {
     GtkTreeViewColumn *column;
-    GtkCellRenderer *renderer;
     PangoLayout* layout;
     int default_width, title_width;
 
@@ -1861,13 +1843,12 @@ gnc_tree_view_add_text_column (GncTreeView *view,
     /* Set up an icon renderer if requested */
     if (icon_name)
     {
-        renderer = gtk_cell_renderer_pixbuf_new ();
-        g_object_set (renderer, "icon-name", icon_name, NULL);
-        gtk_tree_view_column_pack_start (column, renderer, FALSE);
+        GtkCellRenderer *renderer_pix = gtk_cell_renderer_pixbuf_new ();
+        g_object_set (renderer_pix, "icon-name", icon_name, NULL);
+        gtk_tree_view_column_pack_start (column, renderer_pix, FALSE);
     }
 
     /* Set up a text renderer and attributes */
-    renderer = gtk_cell_renderer_text_new ();
     gtk_tree_view_column_pack_start (column, renderer, TRUE);
 
     /* Set up the callbacks for when editing */
@@ -1906,6 +1887,70 @@ gnc_tree_view_add_text_column (GncTreeView *view,
 }
 
 
+/** This function adds a new text column to a GncTreeView base view.
+ *  It takes all the parameters necessary to hook a GtkTreeModel
+ *  column to a GtkTreeViewColumn.  If the tree has a state section
+ *  associated with it, this function also wires up the column so that
+ *  its visibility and width are remembered.
+ *
+ *  Parameters are defined in gnc-tree-view.h
+ */
+GtkTreeViewColumn *
+gnc_tree_view_add_text_column (GncTreeView *view,
+                               const gchar *column_title,
+                               const gchar *pref_name,
+                               const gchar *icon_name,
+                               const gchar *sizing_text,
+                               gint model_data_column,
+                               gint model_visibility_column,
+                               GtkTreeIterCompareFunc column_sort_fn)
+{
+    GtkCellRenderer *renderer;
+
+    g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
+
+    renderer = gtk_cell_renderer_text_new ();
+
+    return add_text_column_variant (view, renderer,
+                                    column_title, pref_name,
+                                    icon_name, sizing_text,
+                                    model_data_column,
+                                    model_visibility_column,
+                                    column_sort_fn);
+}
+
+/** This function adds a new text view column to a GncTreeView base view.
+ *  It takes all the parameters necessary to hook a GtkTreeModel
+ *  column to a GtkTreeViewColumn.  If the tree has a state section
+ *  associated with it, this function also wires up the column so that
+ *  its visibility and width are remembered.
+ *
+ *  Parameters are defined in gnc-tree-view.h
+ */
+GtkTreeViewColumn *
+gnc_tree_view_add_text_view_column (GncTreeView *view,
+                                    const gchar *column_title,
+                                    const gchar *pref_name,
+                                    const gchar *icon_name,
+                                    const gchar *sizing_text,
+                                    gint model_data_column,
+                                    gint model_visibility_column,
+                                    GtkTreeIterCompareFunc column_sort_fn)
+{
+    GtkCellRenderer *renderer;
+
+    g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
+
+    renderer = gnc_cell_renderer_text_view_new ();
+
+    return add_text_column_variant (view, renderer,
+                                    column_title, pref_name,
+                                    icon_name, sizing_text,
+                                    model_data_column,
+                                    model_visibility_column,
+                                    column_sort_fn);
+}
+
 
 /** This function adds a new date column to a GncTreeView base view.
  *  It takes all the parameters necessary to hook a GtkTreeModel
