@@ -19,27 +19,16 @@
 
 (define-module (gnucash gnome-utils))
 
-(use-modules (gnucash utilities))
-(use-modules (gnucash gnc-module))
-
 (eval-when (compile load eval expand)
-  (load-extension "libgncmod-gnome-utils" "scm_init_sw_gnome_utils_module"))
+  (load-extension "libgnc-gnome-utils" "scm_init_sw_gnome_utils_module"))
 
-(use-modules (sw_gnome_utils))
-(gnc:module-load "gnucash/app-utils" 0)
+(use-modules (gnucash core-utils))
+(use-modules (gnucash engine))
+(use-modules (gnucash utilities))
+(use-modules (gnucash app-utils))
 
-;; from gnc-menu-extensions.scm
-(export gnc:extension-type)
-(export gnc:extension-name)
-(export gnc:extension-guid)
-(export gnc:extension-documentation)
-(export gnc:extension-path)
-(export gnc:extension-script)
-(export gnc:make-menu-item)
-(export gnc:make-menu)
-(export gnc:make-separator)
-
-(load-from-path "gnc-menu-extensions")
+(load-and-reexport (sw_gnome_utils)
+                   (gnucash gnome-utils gnc-menu-extensions))
 
 ;; this function will receive 1 boolean argument, and can be used for
 ;; any UI init/shutdown routines. For now it will set the
