@@ -31,6 +31,7 @@
 #include "gnc-component-manager.h"
 #include "gnc-session.h"
 
+#include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "Account.h"
 
@@ -55,11 +56,19 @@ typedef enum
     ONLINE
 }GncListType;
 
+typedef struct
+{
+    guint inv_dialog_shown_bayes : 1;
+    guint inv_dialog_shown_nbayes : 1;
+    guint inv_dialog_shown_online : 1;
+}GncInvFlags;
+
 typedef struct
 {
     GtkWidget    *dialog;
     QofSession   *session;
     GtkWidget    *view;
+    GtkTreeModel *model;
     GncListType   type;
 
     GtkWidget    *radio_bayes;
@@ -71,9 +80,14 @@ typedef struct
     GtkWidget    *filter_label;
     gboolean      apply_selection_filter;
 
+    GtkWidget    *total_entries_label;
+    gint          tot_entries;
+    gint          tot_invalid_maps;
 
     GtkWidget    *expand_button;
     GtkWidget    *collapse_button;
+    GtkWidget    *remove_button;
+    GncInvFlags   inv_dialog_shown;
 }ImapDialog;
 
 
@@ -138,16 +152,25 @@ delete_info_nbayes (Account *source_account, gchar *head,
 }
 
 static void
-delete_selected_row (GtkTreeModel *model, GtkTreeIter *iter, ImapDialog *imap_dialog)
+delete_selected_row (ImapDialog *imap_dialog, GtkTreeIter *iter)
 {
     Account     *source_account = NULL;
     gchar       *full_source_account;
     gchar       *head;
     gchar       *category;
     gchar       *match_string;
+    gint         num = 0;
+    GtkTreeIter  parent;
 
-    gtk_tree_model_get (model, iter, SOURCE_ACCOUNT, &source_account, SOURCE_FULL_ACC, &full_source_account,
-                                     HEAD, &head, CATEGORY, &category, MATCH_STRING, &match_string, -1);
+    // get the parent iter and see how many children it has, if 1 we will remove
+    if (gtk_tree_model_iter_parent (imap_dialog->model, &parent, iter))
+        num = gtk_tree_model_iter_n_children (imap_dialog->model, &parent);
+
+    gtk_tree_model_get (imap_dialog->model, iter, SOURCE_ACCOUNT, &source_account,
+                                                  SOURCE_FULL_ACC, &full_source_account,
+                                                  HEAD, &head,
+                                                  CATEGORY, &category,
+                                                  MATCH_STRING, &match_string, -1);
 
     PINFO("Account is '%s', Head is '%s', Category is '%s', Match String is '%s'",
            full_source_account, head, category, match_string);
@@ -158,7 +181,7 @@ delete_selected_row (GtkTreeModel *model, GtkTreeIter *iter, ImapDialog *imap_di
         gint         depth;
 
         // Get the level we are at in the tree-model
-        tree_path = gtk_tree_model_get_path (model, iter);
+        tree_path = gtk_tree_model_get_path (imap_dialog->model, iter);
         depth = gtk_tree_path_get_depth (tree_path);
         gtk_tree_path_free (tree_path);
 
@@ -170,7 +193,15 @@ delete_selected_row (GtkTreeModel *model, GtkTreeIter *iter, ImapDialog *imap_di
 
         if (imap_dialog->type == NBAYES)
             delete_info_nbayes (source_account, head, category, match_string, depth);
+
+        gtk_tree_store_remove (GTK_TREE_STORE(imap_dialog->model), iter);
+
+        if (num == 1 && (imap_dialog->type != ONLINE))
+            gtk_tree_store_remove (GTK_TREE_STORE(imap_dialog->model), &parent);
     }
+    // Clear the total
+    gtk_label_set_text (GTK_LABEL(imap_dialog->total_entries_label), " ");
+
     if (head)
         g_free (head);
     if (category)
@@ -181,23 +212,51 @@ delete_selected_row (GtkTreeModel *model, GtkTreeIter *iter, ImapDialog *imap_di
         g_free (full_source_account);
 }
 
+static gboolean
+find_invalid_mappings_total (GtkTreeModel *model, GtkTreePath *path,
+                             GtkTreeIter *iter, ImapDialog *imap_dialog)
+{
+    Account *source_account = NULL;
+    Account *map_account = NULL;
+    gchar   *head;
+    gint     depth;
+
+    gtk_tree_model_get (model, iter, SOURCE_ACCOUNT, &source_account,
+                                     MAP_ACCOUNT, &map_account,
+                                     HEAD, &head, -1);
+
+    depth = gtk_tree_path_get_depth (path);
+
+    if ((source_account != NULL) && (map_account == NULL))
+    {
+        if (((g_strcmp0 (head, "online_id") == 0) && (depth == 1)) || (depth == 2))
+            imap_dialog->tot_invalid_maps ++;
+    }
+    g_free (head);
+    return FALSE;
+}
+
 static void
 gnc_imap_dialog_delete (ImapDialog *imap_dialog)
 {
     GList            *list, *row;
-    GtkTreeModel     *model;
+    GtkTreeModel     *fmodel;
+    GtkTreeIter       fiter;
     GtkTreeIter       iter;
     GtkTreeSelection *selection;
 
-    model = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
+    fmodel = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(imap_dialog->view));
 
-    list = gtk_tree_selection_get_selected_rows (selection, &model);
+    list = gtk_tree_selection_get_selected_rows (selection, &fmodel);
 
     // Make sure we have some rows selected
     if (g_list_length (list) == 0)
         return;
 
+    // reset the invalid map total
+    imap_dialog->tot_invalid_maps = 0;
+
     // reverse list
     list = g_list_reverse (list);
 
@@ -207,16 +266,149 @@ gnc_imap_dialog_delete (ImapDialog *imap_dialog)
     // Walk the list
     for (row = g_list_first (list); row; row = g_list_next (row))
     {
-        if (gtk_tree_model_get_iter (model, &iter, row->data))
-            delete_selected_row (model, &iter, imap_dialog);
+        if (gtk_tree_model_get_iter (fmodel, &fiter, row->data))
+        {
+            gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(fmodel), &iter, &fiter);
+            delete_selected_row (imap_dialog, &iter);
+        }
     }
     g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
     g_list_free (list);
 
-    get_account_info (imap_dialog);
+    // Enable GUI refresh again
+    gnc_resume_gui_refresh();
+
+    // recount the number of invalid maps
+    gtk_tree_model_foreach (imap_dialog->model,
+                            (GtkTreeModelForeachFunc)find_invalid_mappings_total,
+                            imap_dialog);
+
+    if (imap_dialog->tot_invalid_maps == 0)
+        gtk_widget_hide (imap_dialog->remove_button);
+
+}
+
+static gboolean
+find_invalid_mappings (GtkTreeModel *model, GtkTreePath *path,
+                         GtkTreeIter *iter, GList **rowref_list)
+{
+    Account *source_account = NULL;
+    Account *map_account = NULL;
+    gchar   *head;
+    gint     depth;
+
+    gtk_tree_model_get (model, iter, SOURCE_ACCOUNT, &source_account,
+                                     MAP_ACCOUNT, &map_account,
+                                     HEAD, &head, -1);
+
+    depth = gtk_tree_path_get_depth (path);
+
+    if ((source_account != NULL) && (map_account == NULL))
+    {
+        if (((g_strcmp0 (head, "online_id") == 0) && (depth == 1)) || (depth == 2))
+        {
+             GtkTreeRowReference *rowref = gtk_tree_row_reference_new (model, path);
+             *rowref_list = g_list_append (*rowref_list, rowref);
+        }
+    }
+    g_free (head);
+    return FALSE;
+}
+
+static void
+gnc_imap_remove_invalid_maps (ImapDialog *imap_dialog)
+{
+    GList *rr_list = NULL;
+    GList *node;
+
+    gtk_tree_model_foreach (imap_dialog->model,
+                            (GtkTreeModelForeachFunc)find_invalid_mappings,
+                            &rr_list);
+
+    // reverse the reference list
+    rr_list = g_list_reverse (rr_list);
+
+    // Suspend GUI refreshing
+    gnc_suspend_gui_refresh();
+
+    // Walk the list
+    for (node = rr_list; node != NULL; node = node->next)
+    {
+        GtkTreePath *path = gtk_tree_row_reference_get_path ((GtkTreeRowReference*)node->data);
+
+        if (path)
+        {
+            GtkTreeIter iter;
+
+            if (gtk_tree_model_get_iter (GTK_TREE_MODEL(imap_dialog->model), &iter, path))
+                delete_selected_row (imap_dialog, &iter);
+
+            gtk_tree_path_free (path);
+        }
+    }
 
     // Enable GUI refresh again
     gnc_resume_gui_refresh();
+
+    g_list_foreach (rr_list, (GFunc)gtk_tree_row_reference_free, NULL);
+    g_list_free (rr_list);
+}
+
+static void
+gnc_imap_invalid_maps_dialog (ImapDialog *imap_dialog)
+{
+    gtk_widget_hide (imap_dialog->remove_button);
+
+    if (imap_dialog->tot_invalid_maps > 0)
+    {
+        /* Translators: This is a ngettext(3) message, %d is the number of maps missing */
+        gchar *message = g_strdup_printf (ngettext ("There is %d invalid mapping,\n\nWould you like to remove it now?",
+                                                    "There are %d invalid mappings,\n\nWould you like to remove them now?",
+                                                    imap_dialog->tot_invalid_maps),
+                                                    imap_dialog->tot_invalid_maps);
+
+        gchar *message2 = g_strdup_printf (gettext ("To see the invalid mappings, use a filter of '%s'"), _("Map Account NOT found"));
+
+        gchar *text = g_strdup_printf ("%s\n\n%s\n\n%s", message, message2, _("(Note, if there is a large number, it may take a while)"));
+
+        if (gnc_verify_dialog (GTK_WINDOW (imap_dialog->dialog), FALSE, "%s", text))
+        {
+            gnc_imap_remove_invalid_maps (imap_dialog);
+            gtk_widget_hide (imap_dialog->remove_button);
+        }
+        else
+        {
+            gtk_widget_show (imap_dialog->remove_button);
+
+            if (imap_dialog->type == BAYES)
+                imap_dialog->inv_dialog_shown.inv_dialog_shown_bayes = TRUE;
+            if (imap_dialog->type == NBAYES)
+                imap_dialog->inv_dialog_shown.inv_dialog_shown_nbayes = TRUE;
+            if (imap_dialog->type == ONLINE)
+                imap_dialog->inv_dialog_shown.inv_dialog_shown_online = TRUE;
+        }
+        g_free (message);
+        g_free (message2);
+        g_free (text);
+    }
+}
+
+static void
+gnc_imap_invalid_maps (ImapDialog *imap_dialog)
+{
+    gboolean inv_dialog_shown = FALSE;
+
+    if ((imap_dialog->type == BAYES) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_bayes))
+        inv_dialog_shown = TRUE;
+
+    if ((imap_dialog->type == NBAYES) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_nbayes))
+        inv_dialog_shown = TRUE;
+
+    if ((imap_dialog->type == ONLINE) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_online))
+        inv_dialog_shown = TRUE;
+
+    if (!inv_dialog_shown)
+        gnc_imap_invalid_maps_dialog (imap_dialog);
 }
 
 void
@@ -230,6 +422,10 @@ gnc_imap_dialog_response_cb (GtkDialog *dialog, gint response_id, gpointer user_
         gnc_imap_dialog_delete (imap_dialog);
         return;
 
+    case GTK_RESPONSE_REJECT:
+        gnc_imap_invalid_maps_dialog (imap_dialog);
+        return;
+
     case GTK_RESPONSE_CLOSE:
     default:
         gnc_close_gui_component_by_data (DIALOG_IMAP_CM_CLASS, imap_dialog);
@@ -238,8 +434,8 @@ gnc_imap_dialog_response_cb (GtkDialog *dialog, gint response_id, gpointer user_
 }
 
 static gboolean
-filter_test_and_move_next (GtkTreeModel *model, GtkTreeIter *iter,
-                           const gchar *filter_text, ImapDialog *imap_dialog)
+filter_test_and_move_next (ImapDialog *imap_dialog, GtkTreeIter *iter,
+                           const gchar *filter_text)
 {
     GtkTreePath *tree_path;
     gint         depth;
@@ -248,14 +444,14 @@ filter_test_and_move_next (GtkTreeModel *model, GtkTreeIter *iter,
     const gchar *map_full_acc;
 
     // Read the row
-    gtk_tree_model_get (model, iter, MATCH_STRING, &match_string, MAP_FULL_ACC, &map_full_acc, -1);
+    gtk_tree_model_get (imap_dialog->model, iter, MATCH_STRING, &match_string, MAP_FULL_ACC, &map_full_acc, -1);
 
     // Get the level we are at in the tree-model
-    tree_path = gtk_tree_model_get_path (model, iter);
+    tree_path = gtk_tree_model_get_path (imap_dialog->model, iter);
     depth = gtk_tree_path_get_depth (tree_path);
 
     // Reset filter to TRUE
-    gtk_tree_store_set (GTK_TREE_STORE(model), iter, FILTER, TRUE, -1);
+    gtk_tree_store_set (GTK_TREE_STORE(imap_dialog->model), iter, FILTER, TRUE, -1);
 
     // Check for a filter_text entry
     if (filter_text && *filter_text != '\0')
@@ -264,7 +460,7 @@ filter_test_and_move_next (GtkTreeModel *model, GtkTreeIter *iter,
         {
             if ((g_strrstr (match_string, filter_text) == NULL) &&
                 (g_strrstr (map_full_acc, filter_text) == NULL ))
-                gtk_tree_store_set (GTK_TREE_STORE(model), iter, FILTER, FALSE, -1);
+                gtk_tree_store_set (GTK_TREE_STORE(imap_dialog->model), iter, FILTER, FALSE, -1);
             else
                 gtk_tree_view_expand_to_path (GTK_TREE_VIEW(imap_dialog->view), tree_path);
         }
@@ -275,14 +471,14 @@ filter_test_and_move_next (GtkTreeModel *model, GtkTreeIter *iter,
     else
     {
         gtk_tree_path_next (tree_path);
-        if (!gtk_tree_model_get_iter (model, iter, tree_path))
+        if (!gtk_tree_model_get_iter (imap_dialog->model, iter, tree_path))
         {
             gtk_tree_path_prev (tree_path);
             gtk_tree_path_up (tree_path);
             gtk_tree_path_next (tree_path);
         }
     }
-    valid = gtk_tree_model_get_iter (model, iter, tree_path);
+    valid = gtk_tree_model_get_iter (imap_dialog->model, iter, tree_path);
 
     gtk_tree_path_free (tree_path);
 
@@ -292,14 +488,10 @@ filter_test_and_move_next (GtkTreeModel *model, GtkTreeIter *iter,
 static void
 filter_button_cb (GtkButton *button, ImapDialog *imap_dialog)
 {
-    GtkTreeModel *model, *filter;
     GtkTreeIter   iter;
     gboolean      valid;
     const gchar  *filter_text;
 
-    filter = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
-    model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER(filter));
-
     filter_text = gtk_entry_get_text (GTK_ENTRY(imap_dialog->filter_text_entry));
 
     // Collapse all nodes
@@ -314,11 +506,11 @@ filter_button_cb (GtkButton *button, ImapDialog *imap_dialog)
     if (filter_text && *filter_text != '\0')
         imap_dialog->apply_selection_filter = TRUE;
 
-    valid = gtk_tree_model_get_iter_first (model, &iter);
+    valid = gtk_tree_model_get_iter_first (imap_dialog->model, &iter);
 
     while (valid)
     {
-        valid = filter_test_and_move_next (model, &iter, filter_text, imap_dialog);
+        valid = filter_test_and_move_next (imap_dialog, &iter, filter_text);
     }
     gtk_widget_grab_focus (GTK_WIDGET(imap_dialog->view));
 }
@@ -357,11 +549,28 @@ list_type_selected_cb (GtkToggleButton* button, ImapDialog *imap_dialog)
     else
         type = ONLINE;
 
+    if (type != ONLINE)
+        gtk_widget_grab_focus (GTK_WIDGET(imap_dialog->filter_text_entry));
+
     // Lets do this only on change of list type
     if (type != imap_dialog->type)
     {
+        gboolean inv_dialog_shown = FALSE;
+
         imap_dialog->type = type;
         get_account_info (imap_dialog);
+
+        if ((imap_dialog->type == BAYES) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_bayes))
+            inv_dialog_shown = TRUE;
+
+        if ((imap_dialog->type == NBAYES) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_nbayes))
+            inv_dialog_shown = TRUE;
+
+        if ((imap_dialog->type == ONLINE) && (imap_dialog->inv_dialog_shown.inv_dialog_shown_online))
+            inv_dialog_shown = TRUE;
+
+        if (!inv_dialog_shown)
+            gnc_imap_invalid_maps_dialog (imap_dialog);
     }
 }
 
@@ -382,7 +591,7 @@ show_count_column (ImapDialog *imap_dialog, gboolean show)
 }
 
 static void
-add_to_store (GtkTreeModel *model, GtkTreeIter *iter, const gchar *text, GncImapInfo *imapInfo)
+add_to_store (ImapDialog *imap_dialog, GtkTreeIter *iter, const gchar *text, GncImapInfo *imapInfo)
 {
     gchar       *fullname = NULL;
     gchar       *map_fullname = NULL;
@@ -391,14 +600,22 @@ add_to_store (GtkTreeModel *model, GtkTreeIter *iter, const gchar *text, GncImap
 
     // Do we have a valid map account
     if (imapInfo->map_account == NULL)
+    {
+        // count the total invalid maps
+        imap_dialog->tot_invalid_maps ++;
+
         map_fullname = g_strdup (_("Map Account NOT found"));
+    }
     else
         map_fullname = gnc_account_get_full_name (imapInfo->map_account);
 
+    // count the total entries
+    imap_dialog->tot_entries ++;
+
     PINFO("Add to Store: Source Acc '%s', Head is '%s', Category is '%s', Match '%s', Map Acc '%s', Count is %s",
           fullname, imapInfo->head, imapInfo->category, imapInfo->match_string, map_fullname, imapInfo->count);
 
-    gtk_tree_store_set (GTK_TREE_STORE(model), iter,
+    gtk_tree_store_set (GTK_TREE_STORE(imap_dialog->model), iter,
                         SOURCE_FULL_ACC, fullname, SOURCE_ACCOUNT, imapInfo->source_account,
                         BASED_ON, text,
                         MATCH_STRING, imapInfo->match_string,
@@ -411,7 +628,7 @@ add_to_store (GtkTreeModel *model, GtkTreeIter *iter, const gchar *text, GncImap
 }
 
 static void
-get_imap_info (Account *acc, const gchar *category, GtkTreeModel *model, const gchar *text)
+get_imap_info (ImapDialog *imap_dialog, Account *acc, const gchar *category, const gchar *text)
 {
     GtkTreeIter  toplevel, child;
     GList *imap_list, *node;
@@ -436,8 +653,8 @@ get_imap_info (Account *acc, const gchar *category, GtkTreeModel *model, const g
         PINFO("List length is %d", g_list_length (imap_list));
 
         // Add top level entry of Source full Account and Based on.
-        gtk_tree_store_append (GTK_TREE_STORE(model), &toplevel, NULL);
-        gtk_tree_store_set (GTK_TREE_STORE(model), &toplevel,
+        gtk_tree_store_append (GTK_TREE_STORE(imap_dialog->model), &toplevel, NULL);
+        gtk_tree_store_set (GTK_TREE_STORE(imap_dialog->model), &toplevel,
                         SOURCE_ACCOUNT, acc, SOURCE_FULL_ACC, acc_name,
                         HEAD, head, CATEGORY, category, BASED_ON, text, FILTER, TRUE, -1);
 
@@ -446,8 +663,8 @@ get_imap_info (Account *acc, const gchar *category, GtkTreeModel *model, const g
             GncImapInfo *imapInfo = node->data;
 
             // First add a child entry and pass iter to add_to_store
-            gtk_tree_store_append (GTK_TREE_STORE(model), &child, &toplevel);
-            add_to_store (model, &child, text, imapInfo);
+            gtk_tree_store_append (GTK_TREE_STORE(imap_dialog->model), &child, &toplevel);
+            add_to_store (imap_dialog, &child, text, imapInfo);
 
             // Free the members and structure
             g_free (imapInfo->head);
@@ -464,14 +681,10 @@ get_imap_info (Account *acc, const gchar *category, GtkTreeModel *model, const g
 static void
 show_first_row (ImapDialog *imap_dialog)
 {
-    GtkTreeModel *model, *filter;
     GtkTreeIter   iter;
 
-    filter = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
-    model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER(filter));
-
     // See if there are any entries
-    if (gtk_tree_model_get_iter_first (model, &iter))
+    if (gtk_tree_model_get_iter_first (imap_dialog->model, &iter))
     {
         GtkTreePath *path;
         path = gtk_tree_path_new_first (); // Set Path to first entry
@@ -481,7 +694,7 @@ show_first_row (ImapDialog *imap_dialog)
 }
 
 static void
-get_account_info_bayes (GList *accts, GtkTreeModel *model)
+get_account_info_bayes (ImapDialog *imap_dialog, GList *accts)
 {
     GList   *ptr;
 
@@ -490,12 +703,12 @@ get_account_info_bayes (GList *accts, GtkTreeModel *model)
     {
         Account *acc = ptr->data;
 
-        get_imap_info (acc, NULL, model, _("Bayesian"));
+        get_imap_info (imap_dialog, acc, NULL, _("Bayesian"));
     }
 }
 
 static void
-get_account_info_nbayes (GList *accts, GtkTreeModel *model)
+get_account_info_nbayes (ImapDialog *imap_dialog, GList *accts)
 {
     GList   *ptr;
 
@@ -505,18 +718,18 @@ get_account_info_nbayes (GList *accts, GtkTreeModel *model)
         Account *acc = ptr->data;
 
         // Description
-        get_imap_info (acc, IMAP_FRAME_DESC, model, _("Description Field"));
+        get_imap_info (imap_dialog, acc, IMAP_FRAME_DESC, _("Description Field"));
 
         // Memo
-        get_imap_info (acc, IMAP_FRAME_MEMO, model, _("Memo Field"));
+        get_imap_info (imap_dialog, acc, IMAP_FRAME_MEMO, _("Memo Field"));
 
         // CSV Account Map
-        get_imap_info (acc, IMAP_FRAME_CSV, model, _("CSV Account Map"));
+        get_imap_info (imap_dialog, acc, IMAP_FRAME_CSV, _("CSV Account Map"));
     }
 }
 
 static void
-get_account_info_online (GList *accts, GtkTreeModel *model)
+get_account_info_online (ImapDialog *imap_dialog, GList *accts)
 {
     GList       *ptr;
     GtkTreeIter  toplevel;
@@ -526,31 +739,62 @@ get_account_info_online (GList *accts, GtkTreeModel *model)
     /* Go through list of accounts */
     for (ptr = accts; ptr; ptr = g_list_next (ptr))
     {
+        gchar  *hbci_account_id = NULL;
+        gchar  *hbci_bank_code = NULL;
         gchar  *text = NULL;
         Account *acc = ptr->data;
 
-        // Save source account
-        imapInfo.source_account = acc;
-        imapInfo.head = "online_id";
-        imapInfo.category = " ";
-
-        text = gnc_account_get_map_entry (acc, imapInfo.head);
+        // Check for online_id
+        text = gnc_account_get_map_entry (acc, "online_id", NULL);
 
         if (text != NULL)
         {
+            // Save source account
+            imapInfo.source_account = acc;
+            imapInfo.head = "online_id";
+            imapInfo.category = " ";
+
             if (g_strcmp0 (text, "") == 0)
                 imapInfo.map_account = NULL;
             else
                 imapInfo.map_account = imapInfo.source_account;
 
-            imapInfo.match_string  = text;
+            imapInfo.match_string = text;
             imapInfo.count = " ";
 
             // Add top level entry and pass iter to add_to_store
-            gtk_tree_store_append (GTK_TREE_STORE(model), &toplevel, NULL);
-            add_to_store (model, &toplevel, _("Online Id"), &imapInfo);
+            gtk_tree_store_append (GTK_TREE_STORE(imap_dialog->model), &toplevel, NULL);
+            add_to_store (imap_dialog, &toplevel, _("Online Id"), &imapInfo);
         }
         g_free (text);
+
+        // Check for aqbanking hbci
+        hbci_account_id = gnc_account_get_map_entry (acc, "hbci", "account-id");
+        hbci_bank_code = gnc_account_get_map_entry (acc, "hbci", "bank-code");
+        text = g_strconcat (hbci_bank_code, ",", hbci_account_id, NULL);
+
+        if ((hbci_account_id != NULL) || (hbci_bank_code != NULL))
+        {
+            // Save source account
+            imapInfo.source_account = acc;
+            imapInfo.head = "hbci";
+            imapInfo.category = " ";
+
+            if (g_strcmp0 (text, "") == 0)
+                imapInfo.map_account = NULL;
+            else
+                imapInfo.map_account = imapInfo.source_account;
+
+            imapInfo.match_string = text;
+            imapInfo.count = " ";
+
+            // Add top level entry and pass iter to add_to_store
+            gtk_tree_store_append (GTK_TREE_STORE(imap_dialog->model), &toplevel, NULL);
+            add_to_store (imap_dialog, &toplevel, _("Online HBCI"), &imapInfo);
+        }
+        g_free (hbci_account_id);
+        g_free (hbci_bank_code);
+        g_free (text);
     }
 }
 
@@ -580,22 +824,26 @@ get_account_info (ImapDialog *imap_dialog)
 {
     Account      *root;
     GList        *accts;
-    GtkTreeModel *model, *filter;
+    GtkTreeModel *fmodel;
+    gchar        *total;
 
     /* Get list of Accounts */
     root = gnc_book_get_root_account (gnc_get_current_book());
     accts = gnc_account_get_descendants_sorted (root);
 
-    filter = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
+    imap_dialog->tot_entries = 0;
+    imap_dialog->tot_invalid_maps = 0;
 
-    model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER(filter));
+    fmodel = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
+
+    imap_dialog->model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER(fmodel));
 
     // Disconnect the filter model from the treeview
-    g_object_ref (G_OBJECT(model));
+    g_object_ref (G_OBJECT(imap_dialog->model));
     gtk_tree_view_set_model (GTK_TREE_VIEW(imap_dialog->view), NULL);
 
     // Clear the tree store
-    gtk_tree_store_clear (GTK_TREE_STORE(model));
+    gtk_tree_store_clear (GTK_TREE_STORE(imap_dialog->model));
 
     // Clear the filter
     gtk_entry_set_text (GTK_ENTRY(imap_dialog->filter_text_entry), "");
@@ -609,30 +857,41 @@ get_account_info (ImapDialog *imap_dialog)
 
     if (imap_dialog->type == BAYES)
     {
-        get_account_info_bayes (accts, model);
+        get_account_info_bayes (imap_dialog, accts);
 
         // Show Count Column
         show_count_column (imap_dialog, TRUE);
     }
     else if (imap_dialog->type == NBAYES)
-        get_account_info_nbayes (accts, model);
+        get_account_info_nbayes (imap_dialog, accts);
     else if (imap_dialog->type == ONLINE)
     {
         // Hide Filter Option
         show_filter_option (imap_dialog, FALSE);
-        get_account_info_online (accts, model);
+        get_account_info_online (imap_dialog, accts);
     }
     // create a new filter model and reconnect to treeview
-    filter = gtk_tree_model_filter_new (GTK_TREE_MODEL(model), NULL);
-    gtk_tree_model_filter_set_visible_column (GTK_TREE_MODEL_FILTER(filter), FILTER);
-    g_object_unref (G_OBJECT(model));
+    fmodel = gtk_tree_model_filter_new (GTK_TREE_MODEL(imap_dialog->model), NULL);
+    gtk_tree_model_filter_set_visible_column (GTK_TREE_MODEL_FILTER(fmodel), FILTER);
+    g_object_unref (G_OBJECT(imap_dialog->model));
 
-    gtk_tree_view_set_model (GTK_TREE_VIEW(imap_dialog->view), filter);
-    g_object_unref (G_OBJECT(filter));
+    gtk_tree_view_set_model (GTK_TREE_VIEW(imap_dialog->view), fmodel);
+    g_object_unref (G_OBJECT(fmodel));
 
     // if there are any entries, show first row
     show_first_row (imap_dialog);
 
+    // add the totals
+    total = g_strdup_printf ("%s %d", _("Total Entries"), imap_dialog->tot_entries);
+    gtk_label_set_text (GTK_LABEL(imap_dialog->total_entries_label), total);
+    gtk_widget_show (imap_dialog->total_entries_label);
+    g_free (total);
+
+    if (imap_dialog->tot_invalid_maps > 0)
+        gtk_widget_show (imap_dialog->remove_button);
+    else
+        gtk_widget_hide (imap_dialog->remove_button);
+
     g_list_free (accts);
 }
 
@@ -681,8 +940,8 @@ gnc_imap_dialog_create (GtkWidget *parent, ImapDialog *imap_dialog)
     dialog = GTK_WIDGET(gtk_builder_get_object (builder, "import_map_dialog"));
     imap_dialog->dialog = dialog;
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog), "GncImapDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog), "gnc-id-import-map");
 
     imap_dialog->session = gnc_get_current_session();
     imap_dialog->type = BAYES;
@@ -700,6 +959,7 @@ gnc_imap_dialog_create (GtkWidget *parent, ImapDialog *imap_dialog)
     g_signal_connect (imap_dialog->radio_nbayes, "toggled",
                       G_CALLBACK(list_type_selected_cb), (gpointer)imap_dialog);
 
+    imap_dialog->total_entries_label = GTK_WIDGET(gtk_builder_get_object (builder, "total_entries_label"));
     imap_dialog->filter_text_entry = GTK_WIDGET(gtk_builder_get_object (builder, "filter-text-entry"));
     imap_dialog->filter_label = GTK_WIDGET(gtk_builder_get_object (builder, "filter-label"));
     imap_dialog->filter_button = GTK_WIDGET(gtk_builder_get_object (builder, "filter-button"));
@@ -716,6 +976,8 @@ gnc_imap_dialog_create (GtkWidget *parent, ImapDialog *imap_dialog)
 
     imap_dialog->view = GTK_WIDGET(gtk_builder_get_object (builder, "treeview"));
 
+    imap_dialog->remove_button = GTK_WIDGET(gtk_builder_get_object (builder, "remove_button"));
+
     // Set filter column
     filter = gtk_tree_view_get_model (GTK_TREE_VIEW(imap_dialog->view));
     gtk_tree_model_filter_set_visible_column (GTK_TREE_MODEL_FILTER(filter), FILTER);
@@ -810,5 +1072,7 @@ gnc_imap_dialog (GtkWidget *parent)
     gnc_gui_component_set_session (component_id, imap_dialog->session);
 
     gtk_widget_show (imap_dialog->dialog);
+    gtk_widget_hide (imap_dialog->remove_button);
+    gnc_imap_invalid_maps_dialog (imap_dialog);
     LEAVE(" ");
 }
