@@ -725,6 +725,39 @@ gnc_payment_set_owner (PaymentWindow *pw, GncOwner *owner)
     gnc_payment_dialog_owner_changed(pw);
 }
 
+static void
+gnc_payment_update_style_classes (PaymentWindow *pw)
+{
+    GtkStyleContext *stylectxt = gtk_widget_get_style_context (GTK_WIDGET(pw->dialog));
+    const gchar *style_label = NULL;
+
+    if (gtk_style_context_has_class (stylectxt, "gnc-class-customers"))
+        gtk_style_context_remove_class (stylectxt, "gnc-class-customers");
+
+    if (gtk_style_context_has_class (stylectxt, "gnc-class-vendors"))
+        gtk_style_context_remove_class (stylectxt, "gnc-class-vendors");
+
+    if (gtk_style_context_has_class (stylectxt, "gnc-class-employees"))
+        gtk_style_context_remove_class (stylectxt, "gnc-class-employees");
+
+    switch (pw->owner_type)
+    {
+        case GNC_OWNER_CUSTOMER:
+            style_label = "gnc-class-customers";
+            break;
+        case GNC_OWNER_VENDOR:
+            style_label = "gnc-class-vendors";
+            break;
+        case GNC_OWNER_EMPLOYEE:
+            style_label = "gnc-class-employees";
+            break;
+        default:
+            style_label = "gnc-class-unknown";
+            break;
+    }
+    // Set a secondary style context for this page so it can be easily manipulated with css
+    gtk_style_context_add_class (stylectxt, style_label);
+}
 
 static void
 gnc_payment_set_owner_type (PaymentWindow *pw, GncOwnerType owner_type)
@@ -757,6 +790,7 @@ gnc_payment_set_owner_type (PaymentWindow *pw, GncOwnerType owner_type)
         }
         valid = gtk_tree_model_iter_next (store, &iter);
     }
+    gnc_payment_update_style_classes (pw);
 
     gnc_payment_dialog_owner_type_changed (pw);
 }
@@ -1128,6 +1162,28 @@ static void print_date (G_GNUC_UNUSED GtkTreeViewColumn *tree_column,
     g_free (doc_date_str);
 }
 
+static gint
+doc_sort_func (GtkTreeModel *model,
+               GtkTreeIter  *a,
+               GtkTreeIter  *b,
+               gpointer      user_data)
+{
+    time64 a_date, b_date;
+    gchar *a_id = NULL, *b_id = NULL;
+    int ret;
+
+    gtk_tree_model_get (model, a, 0, &a_date, 1, &a_id, -1);
+    gtk_tree_model_get (model, b, 0, &b_date, 1, &b_id, -1);
+
+    if (a_date < b_date) ret = -1;
+    else if (a_date > b_date) ret = 1;
+    else ret = g_strcmp0 (a_id, b_id);
+
+    g_free (a_id);
+    g_free (b_id);
+    return ret;
+}
+
 static PaymentWindow *
 new_payment_window (GtkWindow *parent, QofBook *book, InitialPaymentInfo *tx_info)
 {
@@ -1188,8 +1244,8 @@ new_payment_window (GtkWindow *parent, QofBook *book, InitialPaymentInfo *tx_inf
     pw->dialog = GTK_WIDGET (gtk_builder_get_object (builder, "payment_dialog"));
     gtk_window_set_transient_for (GTK_WINDOW(pw->dialog), parent);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(pw->dialog), "GncPaymentDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(pw->dialog), "gnc-id-payment");
 
     /* Grab the widgets and build the dialog */
     pw->payment_warning = GTK_WIDGET (gtk_builder_get_object (builder, "payment_warning"));
@@ -1284,10 +1340,16 @@ new_payment_window (GtkWindow *parent, QofBook *book, InitialPaymentInfo *tx_inf
     tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
                                         column, "9,999,999.00");
 
-    gtk_tree_sortable_set_sort_column_id (
-        GTK_TREE_SORTABLE (gtk_tree_view_get_model (GTK_TREE_VIEW (pw->docs_list_tree_view))),
-        0, GTK_SORT_ASCENDING);
+    gtk_tree_sortable_set_default_sort_func
+        (GTK_TREE_SORTABLE (gtk_tree_view_get_model
+                            (GTK_TREE_VIEW (pw->docs_list_tree_view))),
+         doc_sort_func, NULL, NULL);
 
+    gtk_tree_sortable_set_sort_column_id
+        (GTK_TREE_SORTABLE (gtk_tree_view_get_model
+                            (GTK_TREE_VIEW (pw->docs_list_tree_view))),
+         GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID,
+         GTK_SORT_ASCENDING);
 
     box = GTK_WIDGET (gtk_builder_get_object (builder, "acct_window"));
     pw->acct_tree = GTK_WIDGET(gnc_tree_view_account_new (FALSE));
