@@ -39,6 +39,7 @@
 #include "gnc-plugin-basic-commands.h"
 #include "gnc-ui-util.h"
 
+#include "dialog-doclink.h"
 #include "dialog-book-close.h"
 #include "dialog-file-access.h"
 #include "dialog-fincalc.h"
@@ -47,7 +48,6 @@
 #include "dialog-imap-editor.h"
 #include "dialog-sx-since-last-run.h"
 #include "dialog-totd.h"
-#include "dialog-trans-assoc.h"
 #include "assistant-acct-period.h"
 #include "assistant-loan.h"
 #include "gnc-engine.h"
@@ -91,7 +91,7 @@ static void gnc_main_window_cmd_tools_close_book (GtkAction *action, GncMainWind
 static void gnc_main_window_cmd_tools_find_transactions (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_tools_price_editor (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_tools_imap_editor (GtkAction *action, GncMainWindowActionData *data);
-static void gnc_main_window_cmd_tools_trans_assoc (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_main_window_cmd_tools_trans_doclink (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_tools_commodity_editor (GtkAction *action, GncMainWindowActionData *data);
 static void gnc_main_window_cmd_help_totd (GtkAction *action, GncMainWindowActionData *data);
 
@@ -213,9 +213,9 @@ static GtkActionEntry gnc_plugin_actions [] =
         G_CALLBACK (gnc_main_window_cmd_tools_imap_editor)
     },
     {
-        "ToolsTransAssocAction", NULL, N_("_Transaction Associations"), NULL,
-        N_("View all Transaction Associations"),
-        G_CALLBACK (gnc_main_window_cmd_tools_trans_assoc)
+        "ToolsTransLinkedDocsAction", NULL, N_("_Transaction Linked Documents"), NULL,
+        N_("View all Transaction Linked Documents"),
+        G_CALLBACK (gnc_main_window_cmd_tools_trans_doclink)
     },
 
     /* Help menu */
@@ -239,6 +239,14 @@ static const gchar *gnc_plugin_important_actions[] =
     NULL,
 };
 
+/** The following items should be made insensitive at startup time.  The
+ *  sensitivity will be changed by some later event. */
+static const gchar *gnc_plugin_initially_insensitive_actions[] =
+{
+    "FileSaveAction",
+    NULL,
+};
+
 /** These actions are made not sensitive (i.e.,
  * their toolbar and menu items are grayed out and do not send events
  * when clicked) when the current book is "Read Only".
@@ -309,6 +317,11 @@ gnc_plugin_basic_commands_add_to_window (GncPlugin *plugin,
         GncMainWindow *window,
         GQuark type)
 {
+    GtkActionGroup *action_group =
+        gnc_main_window_get_action_group(window, PLUGIN_ACTIONS_NAME);
+    gnc_plugin_update_actions(action_group,
+                              gnc_plugin_initially_insensitive_actions,
+                              "sensitive", FALSE);
     g_signal_connect(window, "page_changed",
                      G_CALLBACK(gnc_plugin_basic_commands_main_window_page_changed),
                      plugin);
@@ -436,6 +449,10 @@ gnc_main_window_cmd_file_open (GtkAction *action, GncMainWindowActionData *data)
     if (!gnc_main_window_all_finish_pending())
         return;
 
+    /* Reset the flag that indicates the conversion of the bayes KVP
+     * entries has been run */
+    gnc_account_reset_convert_bayes_to_flat ();
+
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
 #ifdef HAVE_DBI_DBI_H
     gnc_ui_file_access_for_open (GTK_WINDOW (data->window));
@@ -507,7 +524,7 @@ gnc_main_window_cmd_edit_tax_options (GtkAction *action, GncMainWindowActionData
 {
     g_return_if_fail (data != NULL);
 
-    gnc_tax_info_dialog (GTK_WIDGET (data->window));
+    gnc_tax_info_dialog (GTK_WIDGET (data->window), NULL);
 }
 
 static void
@@ -590,10 +607,10 @@ gnc_main_window_cmd_tools_imap_editor (GtkAction *action, GncMainWindowActionDat
 }
 
 static void
-gnc_main_window_cmd_tools_trans_assoc (GtkAction *action, GncMainWindowActionData *data)
+gnc_main_window_cmd_tools_trans_doclink (GtkAction *action, GncMainWindowActionData *data)
 {
     gnc_set_busy_cursor (NULL, TRUE);
-    gnc_trans_assoc_dialog (GTK_WINDOW (data->window));
+    gnc_doclink_trans_dialog (GTK_WINDOW (data->window));
     gnc_unset_busy_cursor (NULL);
 }
 
