@@ -54,26 +54,34 @@ static void gnc_plugin_budget_cmd_open_budget (GtkAction *action,
         GncMainWindowActionData *data);
 static void gnc_plugin_budget_cmd_copy_budget (GtkAction *action,
         GncMainWindowActionData *data);
+static void gnc_plugin_budget_cmd_delete_budget (GtkAction *action,
+        GncMainWindowActionData *data);
 
 static GtkActionEntry gnc_plugin_actions [] =
 {
     {
-        "NewBudgetAction", NULL, N_("New Budget"), NULL,
-        N_("Create a new Budget"),
+        "NewBudgetAction", NULL, N_("_New Budget"), NULL,
+        N_("Create a new Budget."),
         G_CALLBACK(gnc_plugin_budget_cmd_new_budget)
     },
 
     {
-        "OpenBudgetAction", NULL, N_("Open Budget"), NULL,
-        N_("Open an existing Budget"),
+        "OpenBudgetAction", NULL, N_("_Open Budget"), NULL,
+        N_("Open an existing Budget in a new tab. If none exists a new budget will be created."),
         G_CALLBACK(gnc_plugin_budget_cmd_open_budget)
     },
 
     {
-        "CopyBudgetAction", NULL, N_("Copy Budget"), NULL,
-        N_("Copy an existing Budget"),
+        "CopyBudgetAction", NULL, N_("_Copy Budget"), NULL,
+        N_("Copy an existing Budget."),
         G_CALLBACK(gnc_plugin_budget_cmd_copy_budget)
     },
+    {
+        "DeleteBudgetAction", NULL, N_("_Delete Budget"), NULL,
+        N_("Delete an existing Budget."),
+        G_CALLBACK(gnc_plugin_budget_cmd_delete_budget)
+    },
+
 };
 static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
 
@@ -233,6 +241,26 @@ gnc_plugin_budget_cmd_copy_budget (GtkAction *action,
         gnc_plugin_budget_cmd_new_budget (action, user_data);
 }
 
+/* user selects budget to delete */
+static void
+gnc_plugin_budget_cmd_delete_budget (GtkAction *action,
+                                     GncMainWindowActionData *user_data)
+{
+    GncBudget *bgt;
+    QofBook *book;
+
+    g_return_if_fail (user_data != NULL);
+
+    book = gnc_get_current_book ();
+    if (qof_collection_count (qof_book_get_collection (book, GNC_ID_BUDGET)) == 0)
+        return;
+
+    bgt = gnc_budget_gui_select_budget (GTK_WINDOW(user_data->window), book);
+    if (!bgt) return;
+
+    gnc_budget_gui_delete_budget (bgt);
+}
+
 /************************************************************
  *                     Other Functions                      *
  ************************************************************/
