@@ -53,7 +53,7 @@ void gnc_split_reg2_raise (GNCSplitReg2 *gsr);
 static GtkWidget* add_summary_label (GtkWidget *summarybar,
                                      const char *label_str);
 
-static void gnc_split_reg2_determine_read_only (GNCSplitReg2 *gsr);
+static void gnc_split_reg2_determine_read_only (GNCSplitReg2 *gsr, gboolean show_dialog);
 
 static void gnc_split_reg2_determine_account_pr (GNCSplitReg2 *gsr);
 
@@ -200,7 +200,7 @@ gnc_split_reg2_init2 (GNCSplitReg2 *gsr)
 {
     if (!gsr) return;
 
-    gnc_split_reg2_determine_read_only (gsr);
+    gnc_split_reg2_determine_read_only (gsr, TRUE);
 
     gnc_split_reg2_determine_account_pr (gsr);
 
@@ -934,8 +934,30 @@ gboolean
 gtk_callback_bug_workaround (gpointer argp)
 {
     dialog_args *args = argp;
-    const gchar *read_only = _("This account register is read-only.");
+    const gchar *read_only_this = _("This account register is read-only.");
+    const gchar *read_only_acc = _("The '%s' account register is read-only.");
+    gchar *read_only = NULL;
     GtkWidget *dialog;
+    GNCLedgerDisplay2Type ledger_type = gnc_ledger_display2_type (args->gsr->ledger);
+    Account *acc = gnc_ledger_display2_leader (args->gsr->ledger);
+    const gchar *acc_name = NULL;
+    gchar *tmp = NULL;
+
+    if (acc)
+    {
+        acc_name = xaccAccountGetName (acc);
+
+        if (ledger_type == LD2_SINGLE)
+            read_only = g_strdup_printf (read_only_acc, acc_name);
+        else
+        {
+            gchar *tmp = g_strconcat (acc_name, "+", NULL);
+            read_only = g_strdup_printf (read_only_acc, tmp);
+            g_free (tmp);
+        }
+    }
+    else
+        read_only = g_strdup (read_only_this);
 
     dialog = gtk_message_dialog_new (GTK_WINDOW(args->gsr->window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -946,6 +968,7 @@ gtk_callback_bug_workaround (gpointer argp)
             "%s", args->string);
     gnc_dialog_run (GTK_DIALOG (dialog), GNC_PREF_WARN_REG_IS_READ_ONLY);
     gtk_widget_destroy (dialog);
+    g_free(read_only);
     g_free (args);
     return FALSE;
 }
@@ -955,7 +978,7 @@ gtk_callback_bug_workaround (gpointer argp)
  **/
 static
 void
-gnc_split_reg2_determine_read_only (GNCSplitReg2 *gsr) //this works
+gnc_split_reg2_determine_read_only (GNCSplitReg2 *gsr, gboolean show_dialog)
 {
 
     if (qof_book_is_readonly (gnc_get_current_book()))
@@ -995,7 +1018,8 @@ gnc_split_reg2_determine_read_only (GNCSplitReg2 *gsr) //this works
         gsr->read_only = TRUE;
         /* Put up a warning dialog */
         args->gsr = gsr;
-        g_timeout_add (250, gtk_callback_bug_workaround, args); /* 0.25 seconds */
+        if (show_dialog)
+            g_timeout_add (250, gtk_callback_bug_workaround, args); /* 0.25 seconds */
     }
 }
 
@@ -1102,6 +1126,10 @@ gboolean
 gnc_split_reg2_get_read_only (GNCSplitReg2 *gsr)
 {
     g_assert (gsr);
+
+    // reset read_only flag
+    gsr->read_only = FALSE;
+    gnc_split_reg2_determine_read_only (gsr, FALSE);
     return gsr->read_only;
 }
 
