@@ -36,6 +36,7 @@
 
 #include "gnc-plugin-bi-import.h"
 #include "dialog-bi-import-gui.h"
+#include "gnc-plugin-manager.h"
 
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = G_LOG_DOMAIN;
@@ -99,6 +100,18 @@ gnc_plugin_bi_import_finalize (GObject *object)
 {
 }
 
+/************************************************************
+*                    Plugin Bootstrapping                   *
+************************************************************/
+
+void
+gnc_plugin_bi_import_create_plugin (void)
+{
+    GncPlugin *plugin = gnc_plugin_bi_import_new ();
+
+    gnc_plugin_manager_add_plugin (gnc_plugin_manager_get (), plugin);
+}
+
 /************************************************************
  *                    Command Callbacks                     *
  ************************************************************/
