@@ -104,8 +104,9 @@ gnc_plugin_customer_import_showGUI(GtkWindow *parent)
     gui->entryFilename = GTK_WIDGET(gtk_builder_get_object (builder, "entryFilename"));
     gui->type = "CUSTOMER"; // Set a default type to import
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(gui->dialog), "GncCustomerImportDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(gui->dialog), "gnc-id-customer-import");
+    gnc_widget_style_context_add_class (GTK_WIDGET(gui->dialog), "gnc-class-imports");
 
     gtk_window_set_transient_for (GTK_WINDOW (gui->dialog), parent);
 
@@ -227,7 +228,8 @@ gnc_customer_import_gui_cancel_cb (GtkWidget *widget, gpointer data)
 void
 gnc_customer_import_gui_help_cb (GtkWidget *widget, gpointer data)
 {
-    gnc_gnome_help(HF_HELP, HL_USAGE_BSNSS);
+    CustomerImportGui *gui = data;
+    gnc_gnome_help (GTK_WINDOW(gui->dialog), HF_GUIDE, HL_IMPORT_CUST);
 }
 
 static void
