@@ -232,24 +232,53 @@ gnc_import_add_account(GtkWidget *button, AccountPickerDialog *picker)
 }
 
 
+/***********************************************************
+ * show_warning
+ *
+ * show the warning and disable OK button
+ ************************************************************/
+static void
+show_warning (AccountPickerDialog *picker, gchar *text)
+{
+    gtk_label_set_text (GTK_LABEL(picker->warning), text);
+    gnc_label_set_alignment (picker->warning, 0.0, 0.5);
+    gtk_widget_show_all (GTK_WIDGET(picker->whbox));
+    g_free (text);
+
+    gtk_widget_set_sensitive (picker->ok_button, FALSE); // disable OK button
+}
+
+
 /***********************************************************
  * show_placeholder_warning
  *
- * show the warning when account is a place holder and disable
- * OK button
+ * show the warning when account is a place holder
  ************************************************************/
 static void
 show_placeholder_warning (AccountPickerDialog *picker, const gchar *name)
 {
-    gchar *text = g_strdup_printf (_("The account %s is a placeholder account and does not allow "
+    gchar *text = g_strdup_printf (_("The account '%s' is a placeholder account and does not allow "
                                      "transactions. Please choose a different account."), name);
 
-    gtk_label_set_text (GTK_LABEL(picker->pwarning), text);
-    gnc_label_set_alignment (picker->pwarning, 0.0, 0.5);
-    gtk_widget_show_all (GTK_WIDGET(picker->pwhbox));
-    g_free (text);
+    show_warning (picker, text);
+}
 
-    gtk_widget_set_sensitive (picker->ok_button, FALSE); // disable OK button
+
+/***********************************************************
+ * show_commodity_warning
+ *
+ * show the warning when account is a different commodity to that
+ * required
+ ************************************************************/
+static void
+show_commodity_warning (AccountPickerDialog *picker, const gchar *name)
+{
+    const gchar *com_name = gnc_commodity_get_fullname (picker->new_account_default_commodity);
+    gchar *text = g_strdup_printf (_("The account '%s' has a different commodity to the "
+                                     "one required, '%s'. Please choose a different account."),
+                                      name, com_name);
+
+    show_warning (picker, text);
 }
 
 
@@ -262,9 +291,15 @@ static void
 account_tree_row_changed_cb (GtkTreeSelection *selection,
                              AccountPickerDialog *picker)
 {
-
     Account *sel_account = gnc_tree_view_account_get_selected_account (picker->account_tree);
 
+    if (!sel_account)
+    {
+        gtk_widget_hide (GTK_WIDGET(picker->whbox)); // hide the warning
+        gtk_widget_set_sensitive (picker->ok_button, FALSE); // disable OK button
+        return;
+    }
+
     gtk_widget_set_sensitive (picker->ok_button, TRUE); // enable OK button
 
     /* See if the selected account is a placeholder. */
@@ -274,8 +309,63 @@ account_tree_row_changed_cb (GtkTreeSelection *selection,
 
         show_placeholder_warning (picker, retval_name);
     }
+    else if (picker->new_account_default_commodity &&
+                (!gnc_commodity_equal (xaccAccountGetCommodity (sel_account),
+                 picker->new_account_default_commodity))) // check commodity
+    {
+        const gchar *retval_name = xaccAccountGetName (sel_account);
+        show_commodity_warning (picker, retval_name);
+    }
     else
-        gtk_widget_hide (GTK_WIDGET(picker->pwhbox)); // hide the placeholder warning
+        gtk_widget_hide (GTK_WIDGET(picker->whbox)); // hide the warning
+}
+
+static gboolean
+account_tree_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+    // Expand the tree when the user starts typing, this will allow sub-accounts to be found.
+    if (event->length == 0)
+        return FALSE;
+    
+    switch (event->keyval)
+    {
+        case GDK_KEY_plus:
+        case GDK_KEY_minus:
+        case GDK_KEY_asterisk:
+        case GDK_KEY_slash:
+        case GDK_KEY_KP_Add:
+        case GDK_KEY_KP_Subtract:
+        case GDK_KEY_KP_Multiply:
+        case GDK_KEY_KP_Divide:
+        case GDK_KEY_Up:
+        case GDK_KEY_KP_Up:
+        case GDK_KEY_Down:
+        case GDK_KEY_KP_Down:
+        case GDK_KEY_Home:
+        case GDK_KEY_KP_Home:
+        case GDK_KEY_End:
+        case GDK_KEY_KP_End:
+        case GDK_KEY_Page_Up:
+        case GDK_KEY_KP_Page_Up:
+        case GDK_KEY_Page_Down:
+        case GDK_KEY_KP_Page_Down:
+        case GDK_KEY_Right:
+        case GDK_KEY_Left:
+        case GDK_KEY_KP_Right:
+        case GDK_KEY_KP_Left:
+        case GDK_KEY_space:
+        case GDK_KEY_KP_Space:
+        case GDK_KEY_backslash:
+        case GDK_KEY_Return:
+        case GDK_KEY_ISO_Enter:
+        case GDK_KEY_KP_Enter:
+            return FALSE;
+            break;
+        default:
+            gtk_tree_view_expand_all (GTK_TREE_VIEW(user_data));
+            return FALSE;
+    }
+    return FALSE;
 }
 
 
@@ -351,8 +441,8 @@ Account * gnc_import_select_account(GtkWidget *parent,
             PERR("Error opening the glade builder interface");
         }
         picker->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "account_picker_dialog"));
-        picker->pwhbox = GTK_WIDGET(gtk_builder_get_object (builder, "placeholder_warning_hbox"));
-        picker->pwarning = GTK_WIDGET(gtk_builder_get_object (builder, "placeholder_warning_label"));
+        picker->whbox = GTK_WIDGET(gtk_builder_get_object (builder, "warning_hbox"));
+        picker->warning = GTK_WIDGET(gtk_builder_get_object (builder, "warning_label"));
         picker->ok_button = GTK_WIDGET(gtk_builder_get_object (builder, "okbutton"));
 
         if (parent)
@@ -385,10 +475,13 @@ Account * gnc_import_select_account(GtkWidget *parent,
         }
         gtk_label_set_text((GtkLabel*)online_id_label, account_description_text);
         build_acct_tree(picker);
-
         gtk_window_set_modal(GTK_WINDOW(picker->dialog), TRUE);
         g_signal_connect(picker->account_tree, "row-activated",
                          G_CALLBACK(account_tree_row_activated_cb), picker);
+        
+        /* Connect key press event so we can expand the tree when the user starts typing, allowing
+        * any subaccount to match */
+        g_signal_connect (picker->account_tree, "key-press-event", G_CALLBACK (account_tree_key_press_cb), picker->account_tree);
 
         selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(picker->account_tree));
         g_signal_connect(selection, "changed",
@@ -426,6 +519,14 @@ Account * gnc_import_select_account(GtkWidget *parent,
                     response = GNC_RESPONSE_NEW;
                     break;
                 }
+                else if (picker->new_account_default_commodity &&
+                            (!gnc_commodity_equal (xaccAccountGetCommodity (retval),
+                             picker->new_account_default_commodity))) // check commodity
+                {
+                    show_commodity_warning (picker, retval_name);
+                    response = GNC_RESPONSE_NEW;
+                    break;
+                }
 
                 if ( account_online_id_value != NULL)
                 {
