@@ -46,6 +46,13 @@
 #include "gnc-prefs.h"
 #include "gnc-state.h"
 
+#include "combocell.h"
+#include "datecell.h"
+#include "formulacell-gnome.h"
+#include "pricecell-gnome.h"
+#include "quickfillcell-gnome.h"
+#include "table-gnome.h"
+
 
 /* Register signals */
 enum
@@ -88,6 +95,20 @@ struct _GnucashRegisterClass
 
 /** Implementation *****************************************************/
 
+void
+gnucash_register_add_cell_types (void)
+{
+    gnc_register_add_cell_type (COMBO_CELL_TYPE_NAME, gnc_combo_cell_new);
+    gnc_register_add_cell_type (DATE_CELL_TYPE_NAME, gnc_date_cell_new);
+    gnc_register_add_cell_type (PRICE_CELL_TYPE_NAME,
+                                gnc_price_cell_gnome_new);
+    gnc_register_add_cell_type (QUICKFILL_CELL_TYPE_NAME,
+                                gnc_quickfill_cell_gnome_new);
+    gnc_register_add_cell_type( FORMULA_CELL_TYPE_NAME,
+                                gnc_formula_cell_gnome_new );
+    gnc_table_gnome_init ();
+}
+
 gboolean
 gnucash_register_has_selection (GnucashRegister *reg)
 {
@@ -161,6 +182,33 @@ gnucash_register_refresh_from_prefs (GnucashRegister *reg)
     gnc_header_request_redraw (GNC_HEADER(sheet->header_item));
 }
 
+void
+gnucash_register_reset_sheet_layout (GnucashRegister *reg)
+{
+    GNCHeaderWidths widths;
+    GnucashSheet *sheet;
+    gint current_width;
+
+    g_return_if_fail (reg != NULL);
+
+    sheet = GNUCASH_SHEET(reg->sheet);
+
+    g_return_if_fail (sheet != NULL);
+    g_return_if_fail (GNUCASH_IS_SHEET (sheet));
+
+    current_width = sheet->window_width - 1;
+
+    widths = gnc_header_widths_new ();
+    gnucash_sheet_set_header_widths (sheet, widths);
+
+    gnucash_sheet_styles_set_dimensions (sheet, current_width);
+
+    gnucash_sheet_compile_styles (sheet);
+    gnucash_sheet_table_load (sheet, TRUE);
+    gnucash_sheet_cursor_set_from_table (sheet, TRUE);
+    gnucash_sheet_redraw_all (sheet);
+    gnc_header_widths_destroy (widths);
+}
 
 void
 gnucash_register_goto_virt_cell (GnucashRegister *reg,
@@ -317,9 +365,7 @@ gnucash_register_class_init (GnucashRegisterClass *klass)
 
     gobject_class = G_OBJECT_CLASS (klass);
 
-#if GTK_CHECK_VERSION(3,20,0)
-    gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(klass), "register");
-#endif
+    gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(klass), "gnc-id-register");
 
     register_parent_class = g_type_class_peek_parent (klass);
 
@@ -378,9 +424,6 @@ gnucash_register_init (GnucashRegister *g_reg)
     gtk_widget_set_can_focus (GTK_WIDGET(table), FALSE);
     gtk_widget_set_can_default (GTK_WIDGET(table), FALSE);
 
-    // This sets a style class for when Gtk+ version is less than 3.20
-    gnc_widget_set_css_name (GTK_WIDGET(g_reg), "register");
-
     gtk_grid_set_row_homogeneous (GTK_GRID(table), FALSE);
     gtk_grid_set_column_homogeneous (GTK_GRID(table), FALSE);
 }
@@ -439,7 +482,7 @@ gnucash_register_attach_popup (GnucashRegister *reg,
  *  to pass NULL as second parameter. */
 
 static void
-gnucash_register_configure (GnucashSheet *sheet, gchar * state_section)
+gnucash_register_configure (GnucashSheet *sheet, const gchar * state_section)
 {
     GNCHeaderWidths widths;
     Table *table;
@@ -500,31 +543,6 @@ gnucash_register_configure (GnucashSheet *sheet, gchar * state_section)
     LEAVE(" ");
 }
 
-static gboolean
-gnucash_register_enter_scrollbar (GtkWidget *widget,
-                                  GdkEvent *event, gpointer user_data)
-{
-    GnucashRegister *reg = user_data;
-    GnucashSheet *sheet = GNUCASH_SHEET(reg->sheet);
-    GtkWidget *vscrollbar = sheet->vscrollbar;
-    GtkWidget *hscrollbar = sheet->hscrollbar;
-
-    // There seems to be a problem with the scrollbar slider not being
-    // updated as the mouse moves possibly related to the following bug
-    // https://bugs.gnucash.org/show_bug.cgi?id=765410
-    // If they are hidden and shown it seems to fix it.
-
-    gtk_widget_hide (GTK_WIDGET(vscrollbar));
-    gtk_widget_show (GTK_WIDGET(vscrollbar));
-
-    if (gtk_widget_is_visible (hscrollbar))
-    {
-        gtk_widget_hide (GTK_WIDGET(hscrollbar));
-        gtk_widget_show (GTK_WIDGET(hscrollbar));
-    }
-    return FALSE;
-}
-
 
 static GtkWidget *
 gnucash_register_create_widget (Table *table)
@@ -571,9 +589,6 @@ gnucash_register_create_widget (Table *table)
     gtk_widget_show (scrollbar);
     GNUCASH_SHEET(sheet)->vscrollbar = scrollbar;
 
-    g_signal_connect(G_OBJECT(scrollbar), "enter-notify-event",
-                      G_CALLBACK(gnucash_register_enter_scrollbar), reg);
-
     scrollbar = gtk_scrollbar_new (GTK_ORIENTATION_HORIZONTAL, GNUCASH_SHEET(sheet)->hadj);
     gtk_grid_attach (GTK_GRID(widget), GTK_WIDGET(scrollbar), 0, 2, 1, 1);
     gtk_widget_set_hexpand (GTK_WIDGET(scrollbar), TRUE);
@@ -586,9 +601,6 @@ gnucash_register_create_widget (Table *table)
     reg->hscrollbar_visible = TRUE;
     GNUCASH_SHEET(sheet)->hscrollbar = scrollbar;
 
-    g_signal_connect(G_OBJECT(scrollbar), "enter-notify-event",
-                      G_CALLBACK(gnucash_register_enter_scrollbar), reg);
-
     g_signal_connect (GNUCASH_SHEET(sheet)->hadj, "changed",
                       G_CALLBACK (gnucash_register_update_hadjustment), reg);
 
@@ -597,7 +609,7 @@ gnucash_register_create_widget (Table *table)
 
 
 GtkWidget *
-gnucash_register_new (Table *table, gchar *state_section)
+gnucash_register_new (Table *table, const gchar *state_section)
 {
     GnucashRegister *reg;
     GtkWidget *widget;
@@ -632,3 +644,18 @@ GnucashSheet *gnucash_register_get_sheet (GnucashRegister *reg)
     return GNUCASH_SHEET(reg->sheet);
 }
 
+
+void
+gnucash_register_set_open_doclink_cb (GnucashRegister *reg,
+                                      GFunc cb, gpointer cb_data)
+{
+    GnucashSheet *sheet;
+
+    if (!reg || !reg->sheet)
+        return;
+    sheet = GNUCASH_SHEET(reg->sheet);
+    sheet->open_doclink_cb = cb;
+    sheet->open_doclink_cb_data = cb_data;
+}
+
+
