@@ -99,10 +99,15 @@ style_dimensions_destroy (BlockDimensions *dimensions)
     if (dimensions == NULL)
         return;
 
-    g_table_destroy (dimensions->cell_dimensions);
-    dimensions->cell_dimensions = NULL;
+    dimensions->refcount--;
 
-    g_free(dimensions);
+    if (dimensions->refcount == 0)
+    {
+        g_table_destroy (dimensions->cell_dimensions);
+        dimensions->cell_dimensions = NULL;
+
+        g_free(dimensions);
+    }
 }
 
 
@@ -153,6 +158,10 @@ compute_row_width (BlockDimensions *dimensions, int row, int col1, int col2)
     {
         CellDimensions *cd;
         cd = g_table_index (dimensions->cell_dimensions, row, j);
+
+        if (!cd)
+            continue;
+
         width += cd->pixel_width;
     }
 
@@ -185,7 +194,7 @@ set_dimensions_pass_one (GnucashSheet *sheet, CellBlock *cursor,
                                 row, col);
 
             cell = gnc_cellblock_get_cell (cursor, row, col);
-            if (!cell)
+            if (!cell || !cd)
                 continue;
 
             text = cell->sample_text;
@@ -200,6 +209,11 @@ set_dimensions_pass_one (GnucashSheet *sheet, CellBlock *cursor,
                 width += gnc_item_edit_get_margin (item_edit, left_right) +
                          gnc_item_edit_get_padding_border (item_edit, left_right);
 
+                // This is used on new popup cells to get the default
+                // width of text plus toggle button.
+                if (cell && cell->is_popup)
+                    width += gnc_item_edit_get_button_width (item_edit) + 2;  // + 2 for the button margin
+
                 cd->pixel_height += gnc_item_edit_get_margin (item_edit, top_bottom) +
                                     gnc_item_edit_get_padding_border (item_edit, top_bottom);
             }
@@ -215,15 +229,9 @@ set_dimensions_pass_one (GnucashSheet *sheet, CellBlock *cursor,
             if (cd->pixel_width > 0)
                 continue;
 
-            // This is used on new account popup cells to get the default
-            // width of text plus toggle button.
-            if (cell && cell->is_popup)
-                width += cd->pixel_height; // toggle button is square, use cell height
-
             cd->pixel_width = MAX (cd->pixel_width, width);
         }
 
-        cd = g_table_index (dimensions->cell_dimensions, row, 0);
         dimensions->height += max_height;
     }
 
@@ -233,6 +241,9 @@ set_dimensions_pass_one (GnucashSheet *sheet, CellBlock *cursor,
         {
             cd = g_table_index (dimensions->cell_dimensions,
                                 row, col);
+            if (!cd)
+                continue;
+
             cd->pixel_height = max_height;
         }
     }
@@ -272,6 +283,9 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
     {
         cd = g_table_index (cd_table, 0, col);
 
+        if (!cd)
+            continue;
+
         widths[col] = cd->pixel_width;
         width += cd->pixel_width;
     }
@@ -288,8 +302,10 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
 
             cd = g_table_index (cd_table, 0, col);
 
+            if (!cd)
+                continue;
+
             cd->pixel_width += (default_width - width);
-            width += (default_width - width);
             widths[col] = cd->pixel_width;
 
             break;
@@ -311,7 +327,8 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
 
             cd = g_table_index (cd_table, 0, col);
 
-            old_width = cd->pixel_width;
+            if (!cd)
+                continue;
 
             cd->pixel_width += (default_width - width);
 
@@ -330,7 +347,6 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
 
             cd->pixel_width = MAX (cd->pixel_width, sample_width);
 
-            width += cd->pixel_width - old_width;
             widths[col] = cd->pixel_width;
 
             break;
@@ -353,6 +369,9 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
             {
                 cd = g_table_index (cd_table, row, col);
 
+                if (!cd)
+                    continue;
+
                 cd->pixel_width = widths[col];
             }
     }
@@ -389,7 +408,7 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
                     continue;
                 }
 
-                if (!cd->can_span_over)
+                if (!cd || !cd->can_span_over)
                     continue;
 
                 if (cd_span == NULL)
@@ -439,6 +458,9 @@ compute_cell_origins_x (BlockDimensions *dimensions)
 
             cd = g_table_index (dimensions->cell_dimensions, i, j);
 
+            if (!cd)
+                continue;
+
             cd->origin_x = x;
             x += cd->pixel_width;
         }
@@ -457,9 +479,17 @@ compute_cell_origins_y (BlockDimensions *dimensions)
         for (j = 0; j < dimensions->ncols; j++)
         {
             cd = g_table_index (dimensions->cell_dimensions, i, j);
+
+            if (!cd)
+                continue;
+
             cd->origin_y = y;
         }
         cd = g_table_index (dimensions->cell_dimensions, i, 0);
+
+        if (!cd)
+            continue;
+
         y += cd->pixel_height;
     }
 }
@@ -560,6 +590,7 @@ gnucash_sheet_set_col_width (GnucashSheet *sheet, int col, int width)
     g_return_if_fail (col < style->ncols);
 
     cd = gnucash_style_get_cell_dimensions (style, 0, col);
+    if (!cd) return;
 
     /* adjust the overall width of this style */
     diff = cd->pixel_width - width;
@@ -644,7 +675,7 @@ destroy_style_helper (gpointer key, gpointer value, gpointer user_data)
     SheetBlockStyle *style = value;
     GnucashSheet *sheet = user_data;
 
-    gnucash_sheet_style_destroy (sheet, style);
+    gnucash_sheet_style_unref (sheet, style);
     g_free (cursor_name);
 }
 
@@ -674,10 +705,12 @@ gnucash_sheet_create_styles (GnucashSheet *sheet)
     for (node = cursors; node; node = node->next)
     {
         CellBlock *cursor = node->data;
+        SheetBlockStyle *style = gnucash_sheet_style_new (sheet, cursor);
 
+        gnucash_sheet_style_ref (sheet, style);
         g_hash_table_insert (sheet->cursor_styles,
                              g_strdup (cursor->cursor_name),
-                             gnucash_sheet_style_new (sheet, cursor));
+                             style);
     }
 }
 
@@ -706,9 +739,9 @@ gnucash_sheet_style_destroy (GnucashSheet *sheet, SheetBlockStyle *style)
 
     if (style->dimensions->refcount == 0)
     {
+        style_dimensions_destroy (style->dimensions);
         g_hash_table_remove (sheet->dimensions_hash_table,
                              style_get_key (style));
-        style_dimensions_destroy (style->dimensions);
     }
 
     g_free (style);
@@ -728,6 +761,7 @@ gnucash_sheet_style_get_cell_pixel_rel_coords (SheetBlockStyle *style,
     g_return_if_fail (cell_col >= 0 && cell_col <= style->ncols);
 
     cd = gnucash_style_get_cell_dimensions (style, cell_row, cell_col);
+    if (!cd) return;
 
     *x = cd->origin_x;
     *y = cd->origin_y;
@@ -769,6 +803,9 @@ gnucash_sheet_get_style_from_table (GnucashSheet *sheet,
 
     vcell = gnc_table_get_virtual_cell (table, vcell_loc);
 
+    if (!vcell)
+        return NULL;
+
     cursor = vcell->cellblock;
 
     style = gnucash_sheet_get_style_from_cursor (sheet,
@@ -798,7 +835,7 @@ gnucash_sheet_get_style_from_cursor (GnucashSheet *sheet,
  */
 
 void
-gnucash_style_ref (SheetBlockStyle *style)
+gnucash_sheet_style_ref (GnucashSheet *sheet, SheetBlockStyle *style)
 {
     g_return_if_fail (style != NULL);
 
@@ -807,14 +844,14 @@ gnucash_style_ref (SheetBlockStyle *style)
 
 
 void
-gnucash_style_unref (SheetBlockStyle *style)
+gnucash_sheet_style_unref (GnucashSheet *sheet, SheetBlockStyle *style)
 {
     g_return_if_fail (style != NULL);
 
     style->refcount--;
 
-    if (style->refcount < 0)
-        g_warning ("Unbalanced Style ref/unref");
+    if (style->refcount == 0)
+        gnucash_sheet_style_destroy (sheet, style);
 }
 
 typedef struct
@@ -951,7 +988,7 @@ gnucash_sheet_set_header_widths (GnucashSheet *sheet,
                                                     row, col);
 
             cell = gnc_cellblock_get_cell (header, row, col);
-            if (!cell || !cell->cell_name)
+            if (!cell || !cell->cell_name || !cd)
                 continue;
 
             cd->pixel_width = gnc_header_widths_get_width
