@@ -21,8 +21,105 @@
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 
 
-(use-modules (gnucash core-utils)
-             (gnucash gettext))
+(define-module (gnucash app-utils date-utilities))
+
+(eval-when (compile load eval expand)
+  (load-extension "libgnc-app-utils" "scm_init_sw_app_utils_module"))
+
+(use-modules (gnucash engine))
+(use-modules (gnucash core-utils))
+(use-modules (gnucash utilities))
+(use-modules (sw_app_utils))
+(use-modules (ice-9 match))
+
+(export gnc:reldate-list)
+(export gnc:date-get-year)
+(export gnc:date-get-quarter)
+(export gnc:date-get-month-day)
+(export gnc:date-get-month)
+(export gnc:date-get-week-day)
+(export gnc:date-get-week)
+(export gnc:date-get-year-day)
+(export gnc:time64-get-year)
+(export gnc:time64-get-quarter)
+(export gnc:time64-get-month-day)
+(export gnc:time64-get-month)
+(export gnc:time64-get-week-day)
+(export gnc:time64-get-week)
+(export gnc:time64-get-year-day)
+(export gnc:date-get-year-string)
+(export gnc:date-get-quarter-string)
+(export gnc:date-get-quarter-year-string)
+(export gnc:date-get-month-string)
+(export gnc:date-get-month-year-string)
+(export gnc:date-get-week-year-string)
+(export gnc:leap-year?)
+(export gnc:days-in-year)
+(export gnc:days-in-month)
+(export gnc:date-to-year-fraction)
+(export gnc:date-year-delta)
+(export gnc:date-to-month-fraction)
+(export gnc:date-to-week-fraction)
+(export gnc:date-to-week)
+(export gnc:date-to-day-fraction)
+(export gnc:date-get-fraction-func)
+(export moddatek)
+(export decdate)
+(export incdate)
+(export decdate)
+(export incdate)
+(export gnc:make-date-interval-list)
+(export gnc:make-date-list)
+(export SecDelta)
+(export DayDelta)
+(export WeekDelta)
+(export TwoWeekDelta)
+(export MonthDelta)
+(export QuarterDelta)
+(export HalfYearDelta)
+(export YearDelta)
+(export ThirtyDayDelta)
+(export NinetyDayDelta)
+(export gnc:deltasym-to-delta)
+(export gnc:time64-start-day-time)
+(export gnc:time64-end-day-time)
+(export gnc:time64-previous-day)
+(export gnc:time64-next-day)
+(export gnc:reldate-get-symbol)
+(export gnc:reldate-get-string)
+(export gnc:reldate-get-desc)
+(export gnc:reldate-get-fn)
+(export gnc:get-absolute-from-relative-date)
+(export gnc:get-relative-date-string)
+(export gnc:get-relative-date-desc)
+(export gnc:get-start-cal-year)
+(export gnc:get-end-cal-year)
+(export gnc:get-start-prev-year)
+(export gnc:get-end-prev-year)
+(export gnc:get-start-this-month)
+(export gnc:get-end-this-month)
+(export gnc:get-start-prev-month)
+(export gnc:get-end-prev-month)
+(export gnc:get-start-current-quarter)
+(export gnc:get-end-current-quarter)
+(export gnc:get-start-prev-quarter)
+(export gnc:get-end-prev-quarter)
+(export gnc:get-today)
+(export gnc:get-one-month-ago)
+(export gnc:get-three-months-ago)
+(export gnc:get-six-months-ago)
+(export gnc:get-one-year-ago)
+(export gnc:reldate-initialize)
+(export gnc:get-end-next-month)
+(export gnc:get-end-next-quarter)
+(export gnc:get-end-next-year)
+(export gnc:get-one-month-ahead)
+(export gnc:get-one-year-ahead)
+(export gnc:get-six-months-ahead)
+(export gnc:get-start-next-month)
+(export gnc:get-start-next-quarter)
+(export gnc:get-start-next-year)
+(export gnc:get-three-months-ahead)
 
 ;; get stuff from localtime date vector
 (define (gnc:date-get-year datevec)
@@ -69,7 +166,7 @@
   (gnc-print-time64 (gnc-mktime datevec) "%Y"))
 
 (define (gnc:date-get-quarter-string datevec)
-  (format #f "Q~d" (gnc:date-get-quarter datevec)))
+  (format #f "Q~a" (gnc:date-get-quarter datevec)))
 
 (define (gnc:date-get-quarter-year-string datevec)
   (string-append 
@@ -87,7 +184,7 @@
   (let* ((beginweekt64 (* (gnc:time64-get-week (gnc-mktime datevec)) 7 86400))
          (begin-string (qof-print-date (+ beginweekt64 (* 3 86400))))
          (end-string (qof-print-date (+ beginweekt64 (* 9 86400)))))
-    (format #f (_ "~a to ~a") begin-string end-string)))
+    (format #f (G_ "~a to ~a") begin-string end-string)))
 
 ;; is leap year?
 (define (gnc:leap-year? year)
@@ -111,8 +208,8 @@
 (define (gnc:date-to-year-fraction caltime)
   (let ((lt (gnc-localtime caltime)))
     (+ (- (gnc:date-get-year lt) 1970)
-       (/ (- (gnc:date-get-year-day lt) 1.0)
-	  (* 1.0 (gnc:days-in-year (gnc:date-get-year lt)))))))
+       (/ (- (gnc:date-get-year-day lt) 1)
+          (gnc:days-in-year (gnc:date-get-year lt))))))
 
 ;; return the number of years (in floating point format) between two dates.
 (define (gnc:date-year-delta caltime1 caltime2)
@@ -147,9 +244,9 @@
 ;; convert a date in seconds since 1970 into # of months since 1970
 (define (gnc:date-to-month-fraction caltime)
   (let ((lt (gnc-localtime caltime)))
-    (+ (* 12 (- (gnc:date-get-year lt) 1970.0))
+    (+ (* 12 (- (gnc:date-get-year lt) 1970))
        (gnc:date-get-month lt) -1
-       (/ (- (gnc:date-get-month-day lt) 1.0)
+       (/ (- (gnc:date-get-month-day lt) 1)
           (gnc:days-in-month
 	   (gnc:date-get-month lt)
 	   (gnc:date-get-year lt))))))
@@ -206,17 +303,6 @@
 (define (decdate adate delta) (moddate - adate delta ))
 (define (incdate adate delta) (moddate + adate delta ))
 
-;; date-granularity comparison functions.
-
-(define (gnc:time64-le-date t1 t2)
-  (issue-deprecation-warning "gnc:time64-le-date is unused")
-  (<= (time64CanonicalDayTime t1)
-      (time64CanonicalDayTime t2)))
-
-(define (gnc:time64-ge-date t1 t2)
-  (issue-deprecation-warning "gnc:time64-ge-date is unused")
-  (gnc:time64-le-date t2 t1))
-
 ;; returns #t if adding 1 to mday causes a month change.
 (define (end-month? date)
   (let ((nextdate (gnc-localtime date)))
@@ -425,43 +511,23 @@
 (define (gnc:reldate-get-desc x) (vector-ref x 2))
 (define (gnc:reldate-get-fn x) (vector-ref x 3))
 
-(define (gnc:make-reldate-hash hash reldate-list)
-  (issue-deprecation-warning "gnc:make-reldate-hash is deprecated.")
-  (map (lambda (reldate) (hash-set! 
-			  hash 
-			  (gnc:reldate-get-symbol reldate)
-			  reldate))
-       reldate-list))
-
-;; the following two variables will be inlined and can be deprecated
-(define gnc:reldate-string-db (gnc:make-string-database)) ;deprecate
-(define gnc:relative-date-values '())                     ;deprecate
-
 ;; the globally available hash of reldates (hash-key = reldate
-;; symbols, hash-value = a vector, reldate data). aim to deprecate it
-;; being exported.
-(define gnc:relative-date-hash (make-hash-table))
+;; symbols, hash-value = a vector, reldate data).
+(define gnc:relative-date-hash #f)
 
 (define (gnc:get-absolute-from-relative-date date-symbol)
   ;; used in options.scm
   (let ((rel-date-data (hash-ref gnc:relative-date-hash date-symbol)))
     (if rel-date-data
         ((gnc:reldate-get-fn rel-date-data))
-        (let* ((msg (_ "Tried to look up an undefined date symbol \
+        (let* ((msg (G_ "Tried to look up an undefined date symbol \
 '~a'. This report was probably saved by a later version of GnuCash. \
 Defaulting to today."))
                (conmsg (format #f msg date-symbol))
-               (uimsg (format #f (_ msg) date-symbol)))
+               (uimsg (format #f (G_ msg) date-symbol)))
           (gnc:gui-warn conmsg uimsg)
           (current-time)))))
 
-(define (gnc:get-relative-date-strings date-symbol)
-  (issue-deprecation-warning "gnc:get-relative-date-strings is unused.")
-  (let ((rel-date-info (hash-ref gnc:relative-date-hash date-symbol)))
-    
-    (cons (gnc:reldate-get-string rel-date-info)
-	  (gnc:relate-get-desc rel-date-info))))
-
 (define (gnc:get-relative-date-string date-symbol)
   ;; used in options.scm
   (let ((rel-date-info (hash-ref gnc:relative-date-hash date-symbol)))
@@ -824,10 +890,17 @@ Defaulting to today."))
 ;;one-month-ago three-months-ago six-months-ago one-year-ago
 ;;start-cur-fin-year start-prev-fin-year end-prev-fin-year
 
-(define (gnc:reldate-initialize)
-  (define gnc:reldate-string-db (gnc:make-string-database))
-  (define gnc:relative-date-values #f)
 
+(define (make-string-database)
+  (define string-hash (make-hash-table))
+  (match-lambda*
+    (('lookup key) (G_ (hash-ref string-hash key)))
+    (('store key string) (hash-set! string-hash key string))
+    (_ (gnc:warn "string-database: bad action"))))
+
+(define gnc:reldate-string-db (make-string-database))
+(define gnc:relative-date-values #f)
+(unless gnc:relative-date-hash
   (gnc:reldate-string-db 
    'store 'start-cal-year-string 
    (N_ "Start of this year"))
@@ -1152,6 +1225,7 @@ Defaulting to today."))
 		 gnc:get-one-year-ahead)))
 
   ;; initialise gnc:relative-date-hash
+  (set! gnc:relative-date-hash (make-hash-table))
   (for-each
    (lambda (reldate)
      (hash-set! gnc:relative-date-hash (gnc:reldate-get-symbol reldate) reldate))
