@@ -46,6 +46,21 @@ typedef QofSession * (*QofSessionCB) (void);
 gchar *gnc_normalize_account_separator (const gchar* separator);
 gboolean gnc_reverse_balance(const Account *account);
 
+/* Backward compatibility *******************************************
+ * Return book's UNREVERSED_BUDGET feature check. */
+gboolean gnc_using_unreversed_budgets (QofBook* book);
+
+/* Backward compatibility *******************************************
+ * Compare book's UNREVERSED_BUDGET with unreverse_check. If they
+ * match, return account reversal according to global pref. If they
+ * don't match, return FALSE. */
+gboolean gnc_reverse_budget_balance (const Account *account, gboolean unreversed);
+
+/* Backward compatibility *******************************************
+ * Return that book's support opening balance accounts by equity type slot */
+void gnc_set_use_equity_type_opening_balance_account (QofBook* book);
+gboolean gnc_using_equity_type_opening_balance_account (QofBook* book);
+
 /* Default directory sections ***************************************/
 #define GNC_PREFS_GROUP_OPEN_SAVE    "dialogs.open-save"
 #define GNC_PREFS_GROUP_EXPORT       "dialogs.export-accounts"
@@ -72,9 +87,11 @@ QofBook * gnc_get_current_book (void);
  * need to check as well for a book with no accounts (root with no children). */
 gboolean gnc_is_new_book (void);
 
-void gnc_set_current_book_tax_name (const gchar *tax_name);
+void gnc_set_current_book_tax_name_type (gboolean name_changed,
+                                            const gchar *tax_name,
+                                            gboolean type_changed,
+                                            const gchar *tax_type);
 const gchar * gnc_get_current_book_tax_name (void);
-void gnc_set_current_book_tax_type (const gchar *tax_type);
 const gchar * gnc_get_current_book_tax_type (void);
 /** Calls gnc_book_option_num_field_source_change to initiate registered
   * callbacks when num_field_source book option changes so that
@@ -177,6 +194,29 @@ const char * gnc_get_reconcile_str (char reconciled_flag);
 const char * gnc_get_reconcile_valid_flags (void);
 const char * gnc_get_reconcile_flag_order (void);
 
+#define WLINK 'w'
+#define FLINK 'f'
+
+/** Get a string containing documentation link valid flags
+ *
+ *  @return a string containing the list of valid link_flags
+ */
+const char *gnc_get_doclink_valid_flags (void);
+
+/** Get a string containing document link flag order
+ *
+ * @return a string containing the document link flag change order
+ */
+const char *gnc_get_doclink_flag_order (void);
+
+/** Get a string representing the document link type
+ *
+ * @param  link_flag The flag to convert into a string
+ *
+ * @return the i18n'd doclink string
+ */
+const char *gnc_get_doclink_str (char link_flag);
+
 typedef enum
 {
     EQUITY_OPENING_BALANCE,
@@ -291,6 +331,9 @@ GNCPrintAmountInfo gnc_account_print_info (const Account *account,
 GNCPrintAmountInfo gnc_split_amount_print_info (Split *split,
         gboolean use_symbol);
 
+GNCPrintAmountInfo gnc_price_print_info (const gnc_commodity *curr,
+        gboolean use_symbol);
+
 GNCPrintAmountInfo gnc_share_print_info_places (int decplaces);
 GNCPrintAmountInfo gnc_default_share_print_info (void);
 GNCPrintAmountInfo gnc_default_price_print_info (const gnc_commodity *curr);
@@ -353,6 +396,10 @@ xaccParseAmountExtended (const char * in_str, gboolean monetary,
 
 void gnc_ui_util_init (void);
 
+/* Remove callback preferences **************************************/
+
+void gnc_ui_util_remove_registered_prefs (void);
+
 #endif
 /** @} */
 /** @} */
