@@ -16,8 +16,141 @@
 ;; Free Software Foundation           Voice:  +1-617-542-5942
 ;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
+
+(define-module (gnucash app-utils options))
+
+(eval-when (compile load eval expand)
+  (load-extension "libgnc-app-utils" "scm_init_sw_app_utils_module"))
+
+(use-modules (gnucash core-utils))
+(use-modules (gnucash engine))
+(use-modules (sw_app_utils))
+(use-modules (gnucash app-utils date-utilities))
+(use-modules (gnucash utilities))
+(use-modules (srfi srfi-1))
 (use-modules (ice-9 regex))
-(use-modules (gnucash gettext))
+
+(export gnc:color->html)
+(export gnc:color-option->hex-string)
+(export gnc:color-option->html)
+(export gnc:currency-accounting-option-get-curr-doc-string)
+(export gnc:currency-accounting-option-get-default-curr)
+(export gnc:currency-accounting-option-get-default-policy)
+(export gnc:currency-accounting-option-get-gain-loss-account-doc-string)
+(export gnc:currency-accounting-option-get-policy-doc-string)
+(export gnc:currency-accounting-option-selected-currency)
+(export gnc:currency-accounting-option-selected-gain-loss-account)
+(export gnc:currency-accounting-option-selected-method)
+(export gnc:currency-accounting-option-selected-policy)
+(export gnc:date-option-absolute-time)
+(export gnc:date-option-get-subtype)
+(export gnc:date-option-relative-time)
+(export gnc:date-option-show-time?)
+(export gnc:date-option-value-type)
+(export gnc:dateformat-get-format)
+(export gnc:generate-restore-forms)
+(export gnc:get-rd-option-data-rd-list)
+(export gnc:get-rd-option-data-show-time)
+(export gnc:get-rd-option-data-subtype)
+(export gnc:lookup-option)
+(export gnc:make-account-list-limited-option)
+(export gnc:make-account-list-option)
+(export gnc:make-account-sel-limited-option)
+(export gnc:make-account-sel-option)
+(export gnc:make-budget-option)
+(export gnc:make-color-option)
+(export gnc:make-commodity-option)
+(export gnc:make-complex-boolean-option)
+(export gnc:make-currency-option)
+(export gnc:make-date-option)
+(export gnc:make-dateformat-option)
+(export gnc:make-font-option)
+(export gnc:make-internal-option)
+(export gnc:make-list-option)
+(export gnc:make-multichoice-callback-option)
+(export gnc:make-multichoice-option)
+(export gnc:make-number-plot-size-option)
+(export gnc:make-number-range-option)
+(export gnc:make-option)
+(export gnc:make-pixmap-option)
+(export gnc:make-query-option)
+(export gnc:make-radiobutton-callback-option)
+(export gnc:make-radiobutton-option)
+(export gnc:make-simple-boolean-option)
+(export gnc:make-string-option)
+(export gnc:make-text-option)
+(export gnc:multichoice-list-lookup)
+(export gnc:new-options)
+(export gnc:option-data)
+(export gnc:option-data-fns)
+(export gnc:option-default-getter)
+(export gnc:option-default-value)
+(export gnc:option-documentation)
+(export gnc:option-generate-restore-form)
+(export gnc:option-get-value)
+(export gnc:option-getter)
+(export gnc:option-index-get-description)
+(export gnc:option-index-get-name)
+(export gnc:option-index-get-value)
+(export gnc:option-kvp->scm)
+(export gnc:option-make-internal!)
+(export gnc:option-name)
+(export gnc:option-number-of-indices)
+(export gnc:option-scm->kvp)
+(export gnc:option-section)
+(export gnc:option-set-changed-callback)
+(export gnc:option-set-default-value)
+(export gnc:option-set-value)
+(export gnc:option-setter)
+(export gnc:option-sort-tag)
+(export gnc:option-strings-getter)
+(export gnc:option-type)
+(export gnc:option-value)
+(export gnc:option-value-get-index)
+(export gnc:option-value-validator)
+(export gnc:option-widget-changed-proc)
+(export gnc:options-clear-changes)
+(export gnc:options-copy-values)
+(export gnc:options-for-each)
+(export gnc:options-for-each-general)
+(export gnc:options-get-default-section)
+(export gnc:options-kvp->scm)
+(export gnc:options-make-date-interval!)
+(export gnc:options-make-end-date!)
+(export gnc:options-register-c-callback)
+(export gnc:options-register-callback)
+(export gnc:options-run-callbacks)
+(export gnc:options-scm->kvp)
+(export gnc:options-set-default-section)
+(export gnc:options-touch)
+(export gnc:options-unregister-callback-id)
+(export gnc:plot-size-option-value)
+(export gnc:plot-size-option-value-type)
+(export gnc:register-option)
+(export gnc:restore-form-generator)
+(export gnc:send-options)
+(export gnc:set-option-kvp->scm)
+(export gnc:set-option-scm->kvp)
+(export gnc:unregister-option)
+(export gnc:value->string)
+
+(export gnc:*option-name-trading-accounts*)
+(export gnc:*option-name-book-currency*)
+(export gnc:*option-section-accounts*)
+(export gnc:*option-name-default-gains-policy*)
+(export gnc:*option-name-default-gain-loss-account*)
+
+(define gnc:*option-section-accounts* OPTION-SECTION-ACCOUNTS)
+(define gnc:*option-name-trading-accounts* OPTION-NAME-TRADING-ACCOUNTS)
+(define gnc:*option-name-currency-accounting* OPTION-NAME-CURRENCY-ACCOUNTING)
+(define gnc:*option-name-book-currency* OPTION-NAME-BOOK-CURRENCY)
+(define gnc:*option-name-default-gains-policy* OPTION-NAME-DEFAULT-GAINS-POLICY)
+(define gnc:*option-name-default-gain-loss-account*
+  OPTION-NAME-DEFAULT-GAINS-LOSS-ACCT-GUID)
+
+(define (gnc:option-get-value book category key)
+  (define acc (if (pair? key) cons list))
+  (qof-book-get-option book (acc category key)))
 
 (define (rpterror-earlier type newoption fallback)
   ;; Translators: the 3 ~a below refer to (1) option type (2) unknown
@@ -27,7 +160,7 @@
 GnuCash. One of the newer ~a options '~a' is not available, fallback to \
 the option '~a'."))
          (console-msg (format #f template type newoption fallback))
-         (ui-msg (format #f (_ template) type newoption fallback)))
+         (ui-msg (format #f (G_ template) type newoption fallback)))
     (gnc:gui-warn console-msg ui-msg)))
 
 (define (gnc:make-option
@@ -1103,7 +1236,7 @@ the option '~a'."))
      (vector (lambda () (length ok-values))
              (lambda (x) (vector-ref (list-ref ok-values x) 0))
              (lambda (x) (vector-ref (list-ref ok-values x) 1))
-             (lambda (x) (vector-ref (ref ok-values x) 2))
+             (lambda (x) (vector-ref (list-ref ok-values x) 2))
              (lambda (x) (gnc:multichoice-list-lookup ok-values x)))
      (lambda () (list-strings ok-values)) #f)))
 
@@ -1680,8 +1813,18 @@ the option '~a'."))
       ("Void Transactions?" "Filter" "Void Transactions")
       ("Void Transactions" "Filter" "Void Transactions")
       ("Account Substring" "Filter" "Account Name Filter")
+      ("Enable links" #f "Enable Links")
+      ;; trep-engine: moved currency options to own tab
+      ("Common Currency" "Currency" "Common Currency")
+      ("Show original currency amount" "Currency" "Show original currency amount")
+      ("Report's currency" "Currency" "Report's currency")
+      ;; new-owner-report.scm, renamed Oct 2020 to differentiate with
+      ;; Document Links:
+      ("Links" #f "Transaction Links")
       ;; invoice.scm, renamed November 2018
       ("Individual Taxes" #f "Use Detailed Tax Summary")
+      ;; income-gst-statement.scm
+      ("default format" #f "Default Format")
       ))
 
   (define (lookup-option section name)
@@ -1702,7 +1845,7 @@ the option '~a'."))
                  (and name-match
                       (let ((new-section (car name-match))
                             (new-name (cadr name-match)))
-                        (gnc:debug
+                        (gnc:warn
                          (format #f "option ~a/~a has been renamed to ~a/~a\n"
                                  section name new-section new-name))
                         (cond
@@ -1934,12 +2077,6 @@ the option '~a'."))
 (define (gnc:generate-restore-forms options options-string)
   ((options 'generate-restore-forms) options-string))
 
-(define (gnc:options-fancy-date book)
-  (let ((date-format (gnc:fancy-date-info book gnc:*fancy-date-format*)))
-    (if (boolean? date-format) ;; date-format does not exist
-        (qof-date-format-get-string (qof-date-format-get))
-       date-format)))
-
 (define (gnc:options-scm->kvp options book clear-option?)
   (if clear-option?
       (qof-book-options-delete book '()))
@@ -1985,19 +2122,6 @@ the option '~a'."))
      (gnc-option-db-register-option db_handle option))
    options))
 
-(define (gnc:save-options options options-string file header truncate?)
-  (issue-deprecation-warning
-   "gnc:save-options is deprecated.")
-  (let ((code (gnc:generate-restore-forms options options-string))
-        (port (false-if-exception
-               (if truncate? 
-                   (open file (logior O_WRONLY O_CREAT O_TRUNC))
-                   (open file (logior O_WRONLY O_CREAT O_APPEND))))))
-    (if port (begin
-               (display header port)
-               (display code port)
-               (close port)))))
-
 (define (gnc:options-make-end-date! options pagename optname sort-tag info)
   (gnc:register-option 
    options  
