@@ -40,7 +40,7 @@ class GncMockSqlBackend : public GncSqlBackend
 public:
     GncMockSqlBackend(GncSqlConnection* conn, QofBook* book) :
         GncSqlBackend(conn, book) {}
-    void session_begin(QofSession*, const char*, bool, bool, bool) override {}
+    void session_begin(QofSession*, const char*, SessionOpenMode) override {}
     void session_end() override {}
     void safe_sync(QofBook* book) override { sync(book); }
 };
