@@ -589,12 +589,8 @@ static std::string migrate_gnc_datahome()
     bfs::path old_dir(g_get_home_dir(), cvt);
     old_dir /= ".gnucash";
 
-    bl::generator gen;
-    gen.add_messages_path(gnc_path_get_datadir());
-    gen.add_messages_domain(PACKAGE);
-
     std::stringstream migration_msg;
-    migration_msg.imbue(gnc_get_locale());
+    migration_msg.imbue(gnc_get_boost_locale());
 
     /* Step 1: copy directory $HOME/.gnucash to $GNC_DATA_HOME */
     auto full_copy = copy_recursive (old_dir, gnc_userdata_home);
@@ -737,7 +733,7 @@ static std::string migrate_gnc_datahome()
 #if defined G_OS_WIN32 ||defined MAC_INTEGRATION
 constexpr auto path_package = PACKAGE_NAME;
 #else
-constexpr auto path_package = PACKAGE;
+constexpr auto path_package = PROJECT_NAME;
 #endif
 
 // Initialize the user's config directory for gnucash
@@ -1024,6 +1020,21 @@ gnc_userdata_dir_as_path (void)
     return gnc_userdata_home;
 }
 
+static const bfs::path&
+gnc_userconfig_dir_as_path (void)
+{
+    if (gnc_userdata_home.empty())
+        /* Don't create missing directories automatically except
+         * if the target directory is the temporary directory. This
+         * should be done properly at a higher level (in the gui
+         * code most likely) very early in application startup.
+         * This call is just a fallback to prevent the code from
+         * crashing because no directories were configured. */
+        gnc_filepath_init();
+
+    return gnc_userconfig_home;
+}
+
 gchar *gnc_file_path_absolute (const gchar *prefix, const gchar *relative)
 {
     bfs::path path_relative (relative);
@@ -1054,7 +1065,7 @@ gchar *gnc_file_path_absolute (const gchar *prefix, const gchar *relative)
 }
 
 /** @fn gchar * gnc_build_userdata_path (const gchar *filename)
- *  @brief Make a path to filename in the user's configuration directory.
+ *  @brief Make a path to filename in the user's gnucash data directory.
  *
  * @param filename The name of the file
  *
@@ -1068,6 +1079,21 @@ gnc_build_userdata_path (const gchar *filename)
     return g_strdup((gnc_userdata_dir_as_path() / filename).string().c_str());
 }
 
+/** @fn gchar * gnc_build_userconfig_path (const gchar *filename)
+ *  @brief Make a path to filename in the user's configuration directory.
+ *
+ * @param filename The name of the file
+ *
+ *  @return An absolute path. The returned string should be freed by the user
+ *  using g_free().
+ */
+
+gchar *
+gnc_build_userconfig_path (const gchar *filename)
+{
+    return g_strdup((gnc_userconfig_dir_as_path() / filename).string().c_str());
+}
+
 /* Test whether c is a valid character for a win32 file name.
  * If so return false, otherwise return true.
  */
@@ -1135,6 +1161,22 @@ gnc_build_data_path (const gchar *filename)
     return g_strdup(path.c_str());
 }
 
+/** @fn gchar * gnc_build_scm_path (const gchar *filename)
+ *  @brief Make a path to filename in the scm directory.
+ *
+ * @param filename The name of the file
+ *
+ *  @return An absolute path. The returned string should be freed by the user
+ *  using g_free().
+ */
+
+gchar *
+gnc_build_scm_path (const gchar *filename)
+{
+    gchar *result = g_build_filename(gnc_path_get_scmdir(), filename, (gchar *)NULL);
+    return result;
+}
+
 /** @fn gchar * gnc_build_report_path (const gchar *filename)
  *  @brief Make a path to filename in the report directory.
  *
@@ -1151,6 +1193,22 @@ gnc_build_report_path (const gchar *filename)
     return result;
 }
 
+/** @fn gchar * gnc_build_reports_path (const gchar *dirname)
+ *  @brief Make a path to dirname in the reports directory.
+ *
+ * @param dirname The name of the subdirectory
+ *
+ *  @return An absolute path. The returned string should be freed by the user
+ *  using g_free().
+ */
+
+gchar *
+gnc_build_reports_path (const gchar *dirname)
+{
+    gchar *result = g_build_filename(gnc_path_get_reportsdir(), dirname, (gchar *)NULL);
+    return result;
+}
+
 /** @fn gchar * gnc_build_stdreports_path (const gchar *filename)
  *  @brief Make a path to filename in the standard reports directory.
  *
@@ -1177,7 +1235,7 @@ gnc_filepath_locate_file (const gchar *default_path, const gchar *name)
     if (g_path_is_absolute (name))
         fullname = g_strdup (name);
     else if (default_path)
-        fullname = g_build_filename (default_path, name, NULL);
+        fullname = g_build_filename (default_path, name, nullptr);
     else
         fullname = gnc_resolve_file_path (name);
 
@@ -1204,7 +1262,7 @@ gnc_filepath_locate_pixmap (const gchar *name)
     gchar *fullname;
     gchar* pkgdatadir = gnc_path_get_pkgdatadir ();
 
-    default_path = g_build_filename (pkgdatadir, "pixmaps", NULL);
+    default_path = g_build_filename (pkgdatadir, "pixmaps", nullptr);
     g_free(pkgdatadir);
     fullname = gnc_filepath_locate_file (default_path, name);
     g_free(default_path);
@@ -1219,7 +1277,7 @@ gnc_filepath_locate_ui_file (const gchar *name)
     gchar *fullname;
     gchar* pkgdatadir = gnc_path_get_pkgdatadir ();
 
-    default_path = g_build_filename (pkgdatadir, "ui", NULL);
+    default_path = g_build_filename (pkgdatadir, "ui", nullptr);
     g_free(pkgdatadir);
     fullname = gnc_filepath_locate_file (default_path, name);
     g_free(default_path);
