@@ -120,6 +120,7 @@ gnc_split_init(Split* split)
     split->balance             = gnc_numeric_zero();
     split->cleared_balance     = gnc_numeric_zero();
     split->reconciled_balance  = gnc_numeric_zero();
+    split->noclosing_balance   = gnc_numeric_zero();
 
     split->gains = GAINS_STATUS_UNKNOWN;
     split->gains_split = NULL;
@@ -513,6 +514,7 @@ xaccSplitReinit(Split * split)
     split->balance             = gnc_numeric_zero();
     split->cleared_balance     = gnc_numeric_zero();
     split->reconciled_balance  = gnc_numeric_zero();
+    split->noclosing_balance   = gnc_numeric_zero();
 
     qof_instance_set_idata(split, 0);
 
@@ -597,6 +599,7 @@ xaccSplitCloneNoKvp (const Split *s)
     split->balance             = s->balance;
     split->cleared_balance     = s->cleared_balance;
     split->reconciled_balance  = s->reconciled_balance;
+    split->noclosing_balance   = s->noclosing_balance;
 
     split->gains = GAINS_STATUS_UNKNOWN;
     split->gains_split = NULL;
@@ -656,7 +659,7 @@ xaccSplitDump (const Split *split, const char *tag)
 {
     char datebuff[MAX_DATE_LENGTH + 1];
     memset (datebuff, 0, sizeof(datebuff));
-    qof_print_date_buff (datebuff, sizeof(datebuff), split->date_reconciled);
+    qof_print_date_buff (datebuff, MAX_DATE_LENGTH, split->date_reconciled);
     printf("  %s Split %p", tag, split);
     printf("    Book:     %p\n", qof_instance_get_book(split));
     printf("    Account:  %p (%s)\n", split->acc,
@@ -679,6 +682,7 @@ xaccSplitDump (const Split *split, const char *tag)
     printf("    CBalance: %s\n", gnc_numeric_to_string(split->cleared_balance));
     printf("    RBalance: %s\n",
            gnc_numeric_to_string(split->reconciled_balance));
+    printf("    NoClose:  %s\n", gnc_numeric_to_string(split->noclosing_balance));
     printf("    idata:    %x\n", qof_instance_get_idata(split));
 }
 #endif
@@ -868,6 +872,9 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         if (!xaccSplitEqualCheckBal ("reconciled ", sa->reconciled_balance,
                                      sb->reconciled_balance))
             return FALSE;
+        if (!xaccSplitEqualCheckBal ("noclosing ", sa->noclosing_balance,
+                                     sb->noclosing_balance))
+            return FALSE;
     }
 
     if (!xaccTransEqual(sa->parent, sb->parent, check_guids, check_txn_splits,
@@ -1272,6 +1279,12 @@ xaccSplitGetBalance (const Split *s)
     return s ? s->balance : gnc_numeric_zero();
 }
 
+gnc_numeric
+xaccSplitGetNoclosingBalance (const Split *s)
+{
+    return s ? s->noclosing_balance : gnc_numeric_zero();
+}
+
 gnc_numeric
 xaccSplitGetClearedBalance (const Split *s)
 {
@@ -1609,8 +1622,7 @@ xaccSplitGetCorrAccountCode(const Split *sa)
     if (!get_corr_account_split(sa, &other_split))
     {
         if (!split_const)
-            /* Translators: This string has a disambiguation prefix */
-            split_const = Q_("Displayed account code of the other account in a multi-split transaction|Split");
+            split_const = C_("Displayed account code of the other account in a multi-split transaction", "Split");
 
         return split_const;
     }
