@@ -54,6 +54,10 @@ extern "C"
 
 #include "qof.h"
 #include "qoflog.h"
+#include <string>
+#include <vector>
+#include <memory>
+#include <algorithm>
 
 #define QOF_LOG_MAX_CHARS 50
 #define QOF_LOG_MAX_CHARS_WITH_ALLOWANCE 100
@@ -63,9 +67,65 @@ extern "C"
 static FILE *fout = NULL;
 static gchar* function_buffer = NULL;
 static gint qof_log_num_spaces = 0;
-static GHashTable *log_table = NULL;
 static GLogFunc previous_handler = NULL;
 static gchar* qof_logger_format = NULL;
+static QofLogModule log_module = "qof";
+
+using StrVec = std::vector<std::string>;
+
+struct ModuleEntry;
+using ModuleEntryPtr = std::unique_ptr<ModuleEntry>;
+using MEVec = std::vector<ModuleEntryPtr>;
+
+static constexpr int parts = 4; //Log domain parts vector preallocation size
+static constexpr QofLogLevel default_level = QOF_LOG_WARNING;
+struct ModuleEntry
+{
+    ModuleEntry(std::string name, QofLogLevel level) :
+        m_name{name}, m_level{level} {
+            m_children.reserve(parts);
+        }
+    ~ModuleEntry() = default;
+    std::string m_name;
+    QofLogLevel m_level;
+    MEVec m_children;
+};
+
+static ModuleEntryPtr _modules = NULL;
+
+static ModuleEntry*
+get_modules()
+{
+    if (!_modules)
+        _modules = std::make_unique<ModuleEntry>("", default_level);
+    return _modules.get();
+}
+
+static StrVec
+split_domain (const std::string domain)
+{
+    StrVec domain_parts;
+    domain_parts.reserve(parts);
+    int start = 0;
+    auto pos = domain.find(".");
+    if (pos == std::string::npos)
+    {
+        domain_parts.emplace_back(domain);
+    }
+    else
+    {
+        while (pos != std::string::npos)
+        {
+            auto part_name{domain.substr(start, pos - start)};
+            domain_parts.emplace_back(part_name);
+            start = pos + 1;
+            pos = domain.find(".", start);
+        }
+        auto part_name{domain.substr(start, pos)};
+        domain_parts.emplace_back(part_name);
+    }
+    return domain_parts;
+}
 
 void
 qof_log_indent(void)
@@ -148,9 +208,7 @@ void
 qof_log_init_filename(const gchar* log_filename)
 {
     gboolean warn_about_missing_permission = FALSE;
-    if (log_table == NULL)
-        log_table = g_hash_table_new_full(g_str_hash, g_str_equal,
-                                          g_free, NULL);
+    auto modules = get_modules();
 
     if (!qof_logger_format)
         qof_logger_format = g_strdup ("* %s %*s <%s> %*s%s%s"); //default format
@@ -163,7 +221,7 @@ qof_log_init_filename(const gchar* log_filename)
         if (fout != NULL && fout != stderr && fout != stdout)
             fclose(fout);
 
-        fname = g_strconcat(log_filename, ".XXXXXX.log", NULL);
+        fname = g_strconcat(log_filename, ".XXXXXX.log", nullptr);
 
         if ((fd = g_mkstemp(fname)) != -1)
         {
@@ -194,9 +252,8 @@ qof_log_init_filename(const gchar* log_filename)
     if (!fout)
         fout = stderr;
 
-    // @@fixme really, the userdata is a struct { log_table, fout, previous_handler }
     if (previous_handler == NULL)
-        previous_handler = g_log_set_default_handler(log4glib_handler, log_table);
+        previous_handler = g_log_set_default_handler(log4glib_handler, modules);
 
     if (warn_about_missing_permission)
     {
@@ -219,10 +276,9 @@ qof_log_shutdown (void)
         function_buffer = NULL;
     }
 
-    if (log_table != NULL)
+    if (_modules != NULL)
     {
-        g_hash_table_destroy(log_table);
-        log_table = NULL;
+        _modules = nullptr;
     }
 
     if (previous_handler != NULL)
@@ -236,14 +292,62 @@ void
 qof_log_set_level(QofLogModule log_module, QofLogLevel level)
 {
     if (!log_module || level == 0)
-    {
         return;
-    }
-    if (!log_table)
+
+    auto module_parts = split_domain(log_module);
+    auto module = get_modules();
+    for (auto part : module_parts)
     {
-        log_table = g_hash_table_new(g_str_hash, g_str_equal);
+        auto iter = std::find_if(module->m_children.begin(),
+                              module->m_children.end(),
+                              [part](auto& child){
+                                  return child && part == child->m_name;
+                              });
+        if (iter == module->m_children.end())
+        {
+            auto child = std::make_unique<ModuleEntry>(part, default_level);
+            module->m_children.emplace_back(std::move(child));
+            module = module->m_children.back().get();
+        }
+        else
+        {
+            module = iter->get();
+        }
     }
-    g_hash_table_insert(log_table, g_strdup((gchar*)log_module), GINT_TO_POINTER((gint)level));
+    module->m_level = level;
+}
+
+
+gboolean
+qof_log_check(QofLogModule domain, QofLogLevel level)
+{
+
+    auto module = get_modules();
+    // If the level is < the default then no need to look further.
+    if (level < module->m_level)
+        return TRUE;
+
+    if (!domain)
+        return FALSE;
+
+    auto domain_vec = split_domain(domain);
+
+    for (auto part : domain_vec)
+    {
+        auto iter = std::find_if(module->m_children.begin(),
+                               module->m_children.end(),
+                               [part](auto& child) {
+                                   return child && part == child->m_name; });
+
+        if (iter == module->m_children.end())
+            return FALSE;
+
+        if (level <= (*iter)->m_level)
+            return TRUE;
+
+        module = iter->get();
+    }
+    return FALSE;
 }
 
 const char *
@@ -346,7 +450,7 @@ qof_log_parse_log_config(const char *filename)
         str = g_strdup_printf ("%d", logger_max_name_length);
         if (qof_logger_format)
             g_free (qof_logger_format);
-        qof_logger_format = g_strconcat ("* %s %*s <%-", str, ".", str, "s> %*s%s%s", NULL);
+        qof_logger_format = g_strconcat ("* %s %*s <%-", str, ".", str, "s> %*s%s%s", nullptr);
 
         g_free (str);
         g_strfreev(levels);
@@ -381,59 +485,12 @@ qof_log_parse_log_config(const char *filename)
     g_key_file_free(conf);
 }
 
-gboolean
-qof_log_check(QofLogModule log_domain, QofLogLevel log_level)
-{
-//#define _QLC_DBG(x) x
-#define _QLC_DBG(x)
-    GHashTable *log_levels = log_table;
-    gchar *domain_copy = g_strdup(log_domain == NULL ? "" : log_domain);
-    gchar *dot_pointer = domain_copy;
-    static const QofLogLevel default_log_thresh = QOF_LOG_WARNING;
-    QofLogLevel longest_match_level = default_log_thresh;
-
-    {
-        gpointer match_level;
-        if (log_levels && (match_level = g_hash_table_lookup(log_levels, "")) != NULL)
-            longest_match_level = (QofLogLevel)GPOINTER_TO_INT(match_level);
-    }
-
-_QLC_DBG( { printf("trying [%s] (%d):", log_domain, log_levels != NULL ? g_hash_table_size(log_levels) : 0); });
-    if (G_LIKELY(log_levels))
-    {
-        // e.g., "a.b.c\0" -> "a\0b.c\0" -> "a.b\0c\0", "a.b.c\0"
-        gpointer match_level;
-        while ((dot_pointer = g_strstr_len(dot_pointer, strlen(dot_pointer), ".")) != NULL)
-        {
-            *dot_pointer = '\0';
-            _QLC_DBG( { printf(" [%s]", domain_copy); });
-            if (g_hash_table_lookup_extended(log_levels, domain_copy, NULL, &match_level))
-            {
-                longest_match_level = (QofLogLevel)GPOINTER_TO_INT(match_level);
-                _QLC_DBG(printf("*"););
-            }
-            *dot_pointer = '.';
-            dot_pointer++;
-        }
-
-        _QLC_DBG( { printf(" [%s]", domain_copy); });
-        if (g_hash_table_lookup_extended(log_levels, domain_copy, NULL, &match_level))
-        {
-            longest_match_level = (QofLogLevel)GPOINTER_TO_INT(match_level);
-            _QLC_DBG( { printf("*"); });
-        }
-    }
-    _QLC_DBG( { printf(" found [%d]\n", longest_match_level); });
-    g_free(domain_copy);
-
-    return log_level <= longest_match_level;
-}
-
 void
 qof_log_set_default(QofLogLevel log_level)
 {
     qof_log_set_level("", log_level);
     qof_log_set_level("qof", log_level);
+    qof_log_set_level("qof.unknown", log_level);
 }
 
 const gchar*
