@@ -5,7 +5,7 @@
 # 23 March 2001
 # with slight GnuCash modifications by Christian Stimming <stimming@tuhh.de> 
 # 19 Aug 2001
-
+# and 04 Sep 2020 by Frank H. Ellenberger <frank.h.ellenberger@gmail.com>
 #check args
 if [ $# -eq 0 ]
 then
@@ -23,17 +23,19 @@ then
 	exit 1;
 fi
 
-# Note: Line 3: PROJECT and probably a few other variables are hardcoded
+# Note: Line 2, 3, 9: PROJECT and probably a few other variables are hardcoded
 cat <<!
 # SOME DESCRIPTIVE TITLE. (Glossary)
-# Copyright (C) YEAR THE PROJECT'S COPYRIGHT HOLDER
 # This file is distributed under the same license as the GnuCash package.
+# Copyright (C) YEAR by the GnuCash developers and the translators:
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
 #
 #, fuzzy
 msgid ""
 msgstr ""
-"Project-Id-Version: PROJECT VERSION\n"
+"Project-Id-Version: GnuCash VERSION\n"
+"Report-Msgid-Bugs-To: https://bugs.gnucash.org/enter_bug.cgi?"
+"product=GnuCash&component=Translations\n"
 "POT-Creation-Date: `date +'%Y-%m-%d %H:%M%z'`\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
